@@ -1,11 +1,11 @@
 from typing import Callable
 
-from autoarray.plot.mat_wrap.visuals import Visuals2D
-from autoarray.plot.mat_wrap.include import Include2D
-from autoarray.plot.mat_wrap.mat_plot import MatPlot2D
-from autoarray.plot.mat_wrap.mat_plot import AutoLabels
+from autoarray.plot.visuals.two_d import Visuals2D
+from autoarray.plot.include.two_d import Include2D
+from autoarray.plot.mat_plot.two_d import MatPlot2D
+from autoarray.plot.auto_labels import AutoLabels
 from autoarray.plot.abstract_plotters import Plotter
-from autoarray.dataset.imaging import Imaging
+from autoarray.dataset.imaging.imaging import Imaging
 
 
 class ImagingPlotterMeta(Plotter):
@@ -69,19 +69,19 @@ class ImagingPlotterMeta(Plotter):
         Parameters
         ----------
         image
-            Whether or not to make a 2D plot (via `imshow`) of the image data.
+            Whether to make a 2D plot (via `imshow`) of the image data.
         noise_map
-            Whether or not to make a 2D plot (via `imshow`) of the noise map.
+            Whether to make a 2D plot (via `imshow`) of the noise map.
         psf
-            Whether or not to make a 2D plot (via `imshow`) of the psf.
+            Whether to make a 2D plot (via `imshow`) of the psf.
         inverse_noise_map
-            Whether or not to make a 2D plot (via `imshow`) of the inverse noise map.
+            Whether to make a 2D plot (via `imshow`) of the inverse noise map.
         signal_to_noise_map
-            Whether or not to make a 2D plot (via `imshow`) of the signal-to-noise map.
+            Whether to make a 2D plot (via `imshow`) of the signal-to-noise map.
         absolute_signal_to_noise_map
-            Whether or not to make a 2D plot (via `imshow`) of the absolute signal to noise map.
+            Whether to make a 2D plot (via `imshow`) of the absolute signal to noise map.
         potential_chi_squared_map
-            Whether or not to make a 2D plot (via `imshow`) of the potential chi squared map.
+            Whether to make a 2D plot (via `imshow`) of the potential chi squared map.
         """
 
         if image:
