@@ -1,10 +1,10 @@
 from typing import Callable
 
 from autoarray.plot.abstract_plotters import Plotter
-from autoarray.plot.mat_wrap.visuals import Visuals2D
-from autoarray.plot.mat_wrap.include import Include2D
-from autoarray.plot.mat_wrap.mat_plot import MatPlot2D
-from autoarray.plot.mat_wrap.mat_plot import AutoLabels
+from autoarray.plot.visuals.two_d import Visuals2D
+from autoarray.plot.include.two_d import Include2D
+from autoarray.plot.mat_plot.two_d import MatPlot2D
+from autoarray.plot.auto_labels import AutoLabels
 from autoarray.fit.fit_imaging import FitImaging
 
 
@@ -16,6 +16,7 @@ class FitImagingPlotterMeta(Plotter):
         mat_plot_2d: MatPlot2D = MatPlot2D(),
         visuals_2d: Visuals2D = Visuals2D(),
         include_2d: Include2D = Include2D(),
+        residuals_symmetric_cmap: bool = True,
     ):
         """
         Plots the attributes of `FitImaging` objects using the matplotlib method `imshow()` and many other matplotlib
@@ -41,6 +42,9 @@ class FitImagingPlotterMeta(Plotter):
             Contains visuals that can be overlaid on the plot.
         include_2d
             Specifies which attributes of the `Array2D` are extracted and plotted as visuals.
+        residuals_symmetric_cmap
+            If true, the `residual_map` and `normalized_residual_map` are plotted with a symmetric color map such
+            that `abs(vmin) = abs(vmax)`.
         """
         super().__init__(
             mat_plot_2d=mat_plot_2d, include_2d=include_2d, visuals_2d=visuals_2d
@@ -48,6 +52,7 @@ class FitImagingPlotterMeta(Plotter):
 
         self.fit = fit
         self.get_visuals_2d = get_visuals_2d
+        self.residuals_symmetric_cmap = residuals_symmetric_cmap
 
     def figures_2d(
         self,
@@ -69,19 +74,19 @@ class FitImagingPlotterMeta(Plotter):
         Parameters
         ----------
         image
-            Whether or not to make a 2D plot (via `imshow`) of the image data.
+            Whether to make a 2D plot (via `imshow`) of the image data.
         noise_map
-            Whether or not to make a 2D plot (via `imshow`) of the noise map.
+            Whether to make a 2D plot (via `imshow`) of the noise map.
         signal_to_noise_map
-            Whether or not to make a 2D plot (via `imshow`) of the signal-to-noise map.
+            Whether to make a 2D plot (via `imshow`) of the signal-to-noise map.
         model_image
-            Whether or not to make a 2D plot (via `imshow`) of the model image.
+            Whether to make a 2D plot (via `imshow`) of the model image.
         residual_map
-            Whether or not to make a 2D plot (via `imshow`) of the residual map.
+            Whether to make a 2D plot (via `imshow`) of the residual map.
         normalized_residual_map
-            Whether or not to make a 2D plot (via `imshow`) of the normalized residual map.
+            Whether to make a 2D plot (via `imshow`) of the normalized residual map.
         chi_squared_map
-            Whether or not to make a 2D plot (via `imshow`) of the chi-squared map.
+            Whether to make a 2D plot (via `imshow`) of the chi-squared map.
         """
 
         if image:
@@ -122,6 +127,12 @@ class FitImagingPlotterMeta(Plotter):
                 ),
             )
 
+        cmap_original = self.mat_plot_2d.cmap
+
+        if self.residuals_symmetric_cmap:
+
+            self.mat_plot_2d.cmap = self.mat_plot_2d.cmap.symmetric
+
         if residual_map:
 
             self.mat_plot_2d.plot_array(
@@ -143,6 +154,8 @@ class FitImagingPlotterMeta(Plotter):
                 ),
             )
 
+        self.mat_plot_2d.cmap = cmap_original
+
         if chi_squared_map:
 
             self.mat_plot_2d.plot_array(
