@@ -55,7 +55,7 @@ def w_tilde_data_interferometer_from(
 
     w_tilde_data = np.zeros(image_pixels)
 
-    weight_map_real = visibilities_real / noise_map_real ** 2.0
+    weight_map_real = visibilities_real / noise_map_real**2.0
 
     for ip0 in range(image_pixels):
 
@@ -404,7 +404,8 @@ def curvature_matrix_via_w_tilde_curvature_preload_interferometer_from(
     This function speeds this calculation up in two ways:
 
     1) Instead of using `w_tilde` (dimensions [image_pixels, image_pixels] it uses `w_tilde_preload` (dimensions
-    [image_pixels, 2]). The massive reduction in the size of this matrix in memory allows for much fast computation.
+    [2*y_image_pixels, 2*x_image_pixels]). The massive reduction in the size of this matrix in memory allows for much
+    fast computation.
 
     2) It omits the `mapping_matrix` and instead uses directly the 1D vector that maps every image pixel to a source
     pixel `native_index_for_slim_index`. This exploits the sparsity in the `mapping_matrix` to directly
@@ -418,9 +419,9 @@ def curvature_matrix_via_w_tilde_curvature_preload_interferometer_from(
     pix_indexes_for_sub_slim_index
         The mappings from a data sub-pixel index to a pixelization pixel index.
     pix_size_for_sub_slim_index
-        The number of mappings between each data sub pixel and pixelizaiton pixel.
+        The number of mappings between each data sub pixel and pixelization pixel.
     pix_weights_for_sub_slim_index
-        The weights of the mappings of every data sub pixel and pixelizaiton pixel.
+        The weights of the mappings of every data sub pixel and pixelization pixel.
     native_index_for_slim_index
         An array of shape [total_unmasked_pixels*sub_size] that maps every unmasked sub-pixel to its corresponding
         native 2D pixel using its (y,x) pixel indexes.
@@ -533,9 +534,9 @@ def curvature_matrix_via_w_tilde_curvature_preload_interferometer_from_1(
     pix_indexes_for_sub_slim_index
         The mappings from a data sub-pixel index to a pixelization pixel index.
     pix_size_for_sub_slim_index
-        The number of mappings between each data sub pixel and pixelizaiton pixel.
+        The number of mappings between each data sub pixel and pixelization pixel.
     pix_weights_for_sub_slim_index
-        The weights of the mappings of every data sub pixel and pixelizaiton pixel.
+        The weights of the mappings of every data sub pixel and pixelization pixel.
     native_index_for_slim_index
         An array of shape [total_unmasked_pixels*sub_size] that maps every unmasked sub-pixel to its corresponding
         native 2D pixel using its (y,x) pixel indexes.
@@ -581,10 +582,91 @@ def curvature_matrix_via_w_tilde_curvature_preload_interferometer_from_1(
     return curvature_matrix
 
 
-import numba
+@numba_util.jit()
+def curvature_matrix_via_w_tilde_curvature_preload_interferometer_no_interp_from(
+    curvature_preload: np.ndarray,
+    pix_indexes_for_sub_slim_index: np.ndarray,
+    native_index_for_slim_index: np.ndarray,
+    pix_pixels: int,
+) -> np.ndarray:
+    """
+    Returns the curvature matrix `F` (see Warren & Dye 2003) by computing it using `w_tilde_preload`
+    (see `w_tilde_preload_interferometer_from`) for an interferometer inversion.
 
-# @numba_util.jit()
-@numba.vectorize()
+    To compute the curvature matrix via w_tilde the following matrix multiplication is normally performed:
+
+    curvature_matrix = mapping_matrix.T * w_tilde * mapping matrix
+
+    This function speeds this calculation up in two ways:
+
+    1) Instead of using `w_tilde` (dimensions [image_pixels, image_pixels] it uses `w_tilde_preload` (dimensions
+    [image_pixels, 2]). The massive reduction in the size of this matrix in memory allows for much fast computation.
+
+    2) It omits the `mapping_matrix` and instead uses directly the 1D vector that maps every image pixel to a source
+    pixel `native_index_for_slim_index`. This exploits the sparsity in the `mapping_matrix` to directly
+    compute the `curvature_matrix` (e.g. it condenses the triple matrix multiplication into a double for loop!).
+
+    Parameters
+    ----------
+    curvature_preload
+        A matrix that precomputes the values for fast computation of w_tilde, which in this function is used to bypass
+        the creation of w_tilde altogether and go directly to the `curvature_matrix`.
+    pix_indexes_for_sub_slim_index
+        The mappings from a data sub-pixel index to a pixelization pixel index.
+    pix_size_for_sub_slim_index
+        The number of mappings between each data sub pixel and pixelization pixel.
+    pix_weights_for_sub_slim_index
+        The weights of the mappings of every data sub pixel and pixelization pixel.
+    native_index_for_slim_index
+        An array of shape [total_unmasked_pixels*sub_size] that maps every unmasked sub-pixel to its corresponding
+        native 2D pixel using its (y,x) pixel indexes.
+    pix_pixels
+        The total number of pixels in the pixelization that reconstructs the data.
+
+    Returns
+    -------
+    ndarray
+        The curvature matrix `F` (see Warren & Dye 2003).
+    """
+
+    curvature_matrix = np.zeros((pix_pixels, pix_pixels))
+
+    image_pixels = len(native_index_for_slim_index)
+
+    for ip0 in range(image_pixels):
+
+        ip0_y, ip0_x = native_index_for_slim_index[ip0]
+
+        # This would be used to create multiple source pixels (e.g. sp0 -> sp2) with interpolation.
+
+        sp0 = pix_indexes_for_sub_slim_index[
+            ip0, 0
+        ]  # <- This 0 would iterate over all image-pixel-to-source-pixel interpolations.
+
+        # This would have weights 0.0 -> 1.0 for interpolation.
+
+        ip0_weight = 1.0
+
+        for ip1 in range(image_pixels):
+
+            ip1_y, ip1_x = native_index_for_slim_index[ip1]
+
+            # Same arrays for interpolation case
+
+            sp1 = pix_indexes_for_sub_slim_index[ip1, 0]
+            ip1_weight = 1.0
+
+            y_diff = ip1_y - ip0_y
+            x_diff = ip1_x - ip0_x
+
+            curvature_matrix[sp0, sp1] += (
+                curvature_preload[y_diff, x_diff] * ip0_weight * ip1_weight
+            )
+
+    return curvature_matrix
+
+
+@numba_util.jit()
 def curvature_matrix_via_w_tilde_curvature_preload_interferometer_from_2(
     curvature_preload: np.ndarray,
     native_index_for_slim_index: np.ndarray,
@@ -616,16 +698,16 @@ def curvature_matrix_via_w_tilde_curvature_preload_interferometer_from_2(
         A matrix that precomputes the values for fast computation of w_tilde, which in this function is used to bypass
         the creation of w_tilde altogether and go directly to the `curvature_matrix`.
     pix_indexes_for_sub_slim_index
-        The mappings from a data sub-pixel index to a pixelization pixel index.
+        The mappings from a data sub-pixel index to a pixelization's mesh pixel index.
     pix_size_for_sub_slim_index
-        The number of mappings between each data sub pixel and pixelizaiton pixel.
+        The number of mappings between each data sub pixel and pixelization pixel.
     pix_weights_for_sub_slim_index
-        The weights of the mappings of every data sub pixel and pixelizaiton pixel.
+        The weights of the mappings of every data sub pixel and pixelization pixel.
     native_index_for_slim_index
         An array of shape [total_unmasked_pixels*sub_size] that maps every unmasked sub-pixel to its corresponding
         native 2D pixel using its (y,x) pixel indexes.
     pix_pixels
-        The total number of pixels in the pixelization that reconstructs the data.
+        The total number of pixels in the pixelization's mesh that reconstructs the data.
 
     Returns
     -------
@@ -671,6 +753,177 @@ def curvature_matrix_via_w_tilde_curvature_preload_interferometer_from_2(
     return curvature_matrix
 
 
+# @numba_util.jit()
+def curvature_matrix_via_w_tilde_curvature_preload_interferometer_from_2_no_interp(
+    curvature_preload: np.ndarray,
+    native_index_for_slim_index: np.ndarray,
+    pix_pixels: int,
+    sub_slim_indexes_for_pix_index,
+    sub_slim_sizes_for_pix_index,
+    sub_slim_weights_for_pix_index,
+) -> np.ndarray:
+    """
+    Returns the curvature matrix `F` (see Warren & Dye 2003) by computing it using `w_tilde_preload`
+    (see `w_tilde_preload_interferometer_from`) for an interferometer inversion.
+
+    To compute the curvature matrix via w_tilde the following matrix multiplication is normally performed:
+
+    curvature_matrix = mapping_matrix.T * w_tilde * mapping matrix
+
+    This function speeds this calculation up in two ways:
+
+    1) Instead of using `w_tilde` (dimensions [image_pixels, image_pixels] it uses `w_tilde_preload` (dimensions
+    [image_pixels, 2]). The massive reduction in the size of this matrix in memory allows for much fast computation.
+
+    2) It omits the `mapping_matrix` and instead uses directly the 1D vector that maps every image pixel to a source
+    pixel `native_index_for_slim_index`. This exploits the sparsity in the `mapping_matrix` to directly
+    compute the `curvature_matrix` (e.g. it condenses the triple matrix multiplication into a double for loop!).
+
+    Parameters
+    ----------
+    curvature_preload
+        A matrix that precomputes the values for fast computation of w_tilde, which in this function is used to bypass
+        the creation of w_tilde altogether and go directly to the `curvature_matrix`.
+    pix_indexes_for_sub_slim_index
+        The mappings from a data sub-pixel index to a pixelization's mesh pixel index.
+    pix_size_for_sub_slim_index
+        The number of mappings between each data sub pixel and pixelization pixel.
+    pix_weights_for_sub_slim_index
+        The weights of the mappings of every data sub pixel and pixelization pixel.
+    native_index_for_slim_index
+        An array of shape [total_unmasked_pixels*sub_size] that maps every unmasked sub-pixel to its corresponding
+        native 2D pixel using its (y,x) pixel indexes.
+    pix_pixels
+        The total number of pixels in the pixelization's mesh that reconstructs the data.
+
+    Returns
+    -------
+    ndarray
+        The curvature matrix `F` (see Warren & Dye 2003).
+    """
+
+    curvature_matrix = np.zeros((pix_pixels, pix_pixels))
+
+    for sp0 in range(pix_pixels):
+
+        for sp1 in range(sp0, pix_pixels):
+
+            val = 0.0
+
+            ip0 = sub_slim_indexes_for_pix_index[sp0, 0]
+            ip0_weight = sub_slim_weights_for_pix_index[sp0, 0]
+
+            ip0_y, ip0_x = native_index_for_slim_index[ip0]
+
+            ip1 = sub_slim_indexes_for_pix_index[sp1, 0]
+            ip1_weight = sub_slim_weights_for_pix_index[sp1, 0]
+
+            ip1_y, ip1_x = native_index_for_slim_index[ip1]
+
+            y_diff = ip1_y - ip0_y
+            x_diff = ip1_x - ip0_x
+
+            val += curvature_preload[y_diff, x_diff] * ip0_weight * ip1_weight
+
+            curvature_matrix[sp0, sp1] += val
+
+    for i in range(pix_pixels):
+        for j in range(i, pix_pixels):
+            curvature_matrix[j, i] = curvature_matrix[i, j]
+
+    return curvature_matrix
+
+
+# import numba
+#
+# # @numba_util.jit()
+# @numba.vectorize()
+# def curvature_matrix_via_w_tilde_curvature_preload_interferometer_from_2(
+#     curvature_preload: np.ndarray,
+#     native_index_for_slim_index: np.ndarray,
+#     pix_pixels: int,
+#     sub_slim_indexes_for_pix_index,
+#     sub_slim_sizes_for_pix_index,
+#     sub_slim_weights_for_pix_index,
+# ) -> np.ndarray:
+#     """
+#     Returns the curvature matrix `F` (see Warren & Dye 2003) by computing it using `w_tilde_preload`
+#     (see `w_tilde_preload_interferometer_from`) for an interferometer inversion.
+#
+#     To compute the curvature matrix via w_tilde the following matrix multiplication is normally performed:
+#
+#     curvature_matrix = mapping_matrix.T * w_tilde * mapping matrix
+#
+#     This function speeds this calculation up in two ways:
+#
+#     1) Instead of using `w_tilde` (dimensions [image_pixels, image_pixels] it uses `w_tilde_preload` (dimensions
+#     [image_pixels, 2]). The massive reduction in the size of this matrix in memory allows for much fast computation.
+#
+#     2) It omits the `mapping_matrix` and instead uses directly the 1D vector that maps every image pixel to a source
+#     pixel `native_index_for_slim_index`. This exploits the sparsity in the `mapping_matrix` to directly
+#     compute the `curvature_matrix` (e.g. it condenses the triple matrix multiplication into a double for loop!).
+#
+#     Parameters
+#     ----------
+#     curvature_preload
+#         A matrix that precomputes the values for fast computation of w_tilde, which in this function is used to bypass
+#         the creation of w_tilde altogether and go directly to the `curvature_matrix`.
+#     pix_indexes_for_sub_slim_index
+#         The mappings from a data sub-pixel index to a pixelization pixel index.
+#     pix_size_for_sub_slim_index
+#         The number of mappings between each data sub pixel and pixelization pixel.
+#     pix_weights_for_sub_slim_index
+#         The weights of the mappings of every data sub pixel and pixelization pixel.
+#     native_index_for_slim_index
+#         An array of shape [total_unmasked_pixels*sub_size] that maps every unmasked sub-pixel to its corresponding
+#         native 2D pixel using its (y,x) pixel indexes.
+#     pix_pixels
+#         The total number of pixels in the pixelization that reconstructs the data.
+#
+#     Returns
+#     -------
+#     ndarray
+#         The curvature matrix `F` (see Warren & Dye 2003).
+#     """
+#
+#     curvature_matrix = np.zeros((pix_pixels, pix_pixels))
+#
+#     for sp0 in range(pix_pixels):
+#
+#         ip_size_0 = sub_slim_sizes_for_pix_index[sp0]
+#
+#         for sp1 in range(sp0, pix_pixels):
+#
+#             val = 0.0
+#             ip_size_1 = sub_slim_sizes_for_pix_index[sp1]
+#
+#             for ip0_tmp in range(ip_size_0):
+#
+#                 ip0 = sub_slim_indexes_for_pix_index[sp0, ip0_tmp]
+#                 ip0_weight = sub_slim_weights_for_pix_index[sp0, ip0_tmp]
+#
+#                 ip0_y, ip0_x = native_index_for_slim_index[ip0]
+#
+#                 for ip1_tmp in range(ip_size_1):
+#                     ip1 = sub_slim_indexes_for_pix_index[sp1, ip1_tmp]
+#                     ip1_weight = sub_slim_weights_for_pix_index[sp1, ip1_tmp]
+#
+#                     ip1_y, ip1_x = native_index_for_slim_index[ip1]
+#
+#                     y_diff = ip1_y - ip0_y
+#                     x_diff = ip1_x - ip0_x
+#
+#                     val += curvature_preload[y_diff, x_diff] * ip0_weight * ip1_weight
+#
+#             curvature_matrix[sp0, sp1] += val
+#
+#     for i in range(pix_pixels):
+#         for j in range(i, pix_pixels):
+#             curvature_matrix[j, i] = curvature_matrix[i, j]
+#
+#     return curvature_matrix
+
+
 # import numba
 #
 # # @numba_util.jit()
@@ -708,9 +961,9 @@ def curvature_matrix_via_w_tilde_curvature_preload_interferometer_from_2(
 #     pix_indexes_for_sub_slim_index
 #         The mappings from a data sub-pixel index to a pixelization pixel index.
 #     pix_size_for_sub_slim_index
-#         The number of mappings between each data sub pixel and pixelizaiton pixel.
+#         The number of mappings between each data sub pixel and pixelization pixel.
 #     pix_weights_for_sub_slim_index
-#         The weights of the mappings of every data sub pixel and pixelizaiton pixel.
+#         The weights of the mappings of every data sub pixel and pixelization pixel.
 #     native_index_for_slim_index
 #         An array of shape [total_unmasked_pixels*sub_size] that maps every unmasked sub-pixel to its corresponding
 #         native 2D pixel using its (y,x) pixel indexes.
