@@ -5,9 +5,89 @@ from autoarray import exc
 from autoarray import numba_util
 
 
+@numba_util.jit()
+def zeroth_regularization_matrix_from(coefficient: float, pixels: int) -> np.ndarray:
+    """
+    Apply zeroth order regularization which penalizes every pixel's deviation from zero by addiing non-zero terms
+    to the regularization matrix.
+
+    A complete description of regularization and the `regularization_matrix` can be found in the `Regularization`
+    class in the module `autoarray.inversion.regularization`.
+
+    Parameters
+    ----------
+    pixels
+        The number of pixels in the linear object which is to be regularized, being used to in the inversion.
+    coefficient
+        The regularization coefficients which controls the degree of smoothing of the inversion reconstruction.
+
+    Returns
+    -------
+    np.ndarray
+        The regularization matrix computed using a constant regularization scheme where the effective regularization
+        coefficient of every source pixel is the same.
+    """
+
+    regularization_matrix = np.zeros(shape=(pixels, pixels))
+
+    regularization_coefficient = coefficient**2.0
+
+    for i in range(pixels):
+        regularization_matrix[i, i] += regularization_coefficient
+
+    return regularization_matrix
+
+
 @numba_util.jit()
 def constant_regularization_matrix_from(
-    coefficient: float, pixel_neighbors: np.ndarray, pixel_neighbors_sizes: np.ndarray
+    coefficient: float, neighbors: np.ndarray, neighbors_sizes: np.ndarray
+) -> np.ndarray:
+    """
+    From the pixel-neighbors array, setup the regularization matrix using the instance regularization scheme.
+
+    A complete description of regularizatin and the `regularization_matrix` can be found in the `Regularization`
+    class in the module `autoarray.inversion.regularization`.
+
+    Parameters
+    ----------
+    coefficient
+        The regularization coefficients which controls the degree of smoothing of the inversion reconstruction.
+    neighbors
+        An array of length (total_pixels) which provides the index of all neighbors of every pixel in
+        the Voronoi grid (entries of -1 correspond to no neighbor).
+    neighbors_sizes
+        An array of length (total_pixels) which gives the number of neighbors of every pixel in the
+        Voronoi grid.
+
+    Returns
+    -------
+    np.ndarray
+        The regularization matrix computed using a constant regularization scheme where the effective regularization
+        coefficient of every source pixel is the same.
+    """
+
+    parameters = len(neighbors)
+
+    regularization_matrix = np.zeros(shape=(parameters, parameters))
+
+    regularization_coefficient = coefficient**2.0
+
+    for i in range(parameters):
+        regularization_matrix[i, i] += 1e-8
+        for j in range(neighbors_sizes[i]):
+            neighbor_index = neighbors[i, j]
+            regularization_matrix[i, i] += regularization_coefficient
+            regularization_matrix[i, neighbor_index] -= regularization_coefficient
+
+    return regularization_matrix
+
+
+@numba_util.jit()
+def constant_zeroth_regularization_matrix_from(
+    coefficient: float,
+    coefficient_zeroth: float,
+    neighbors: np.ndarray,
+    neighbors_sizes: np.ndarray,
 ) -> np.ndarray:
     """
     From the pixel-neighbors array, setup the regularization matrix using the instance regularization scheme.
@@ -19,10 +99,10 @@ def constant_regularization_matrix_from(
     ----------
     coefficients
         The regularization coefficients which controls the degree of smoothing of the inversion reconstruction.
-    pixel_neighbors
+    neighbors
         An array of length (total_pixels) which provides the index of all neighbors of every pixel in
         the Voronoi grid (entries of -1 correspond to no neighbor).
-    pixel_neighbors_sizes
+    neighbors_sizes
         An array of length (total_pixels) which gives the number of neighbors of every pixel in the
         Voronoi grid.
 
@@ -33,16 +113,18 @@ def constant_regularization_matrix_from(
         coefficient of every source pixel is the same.
     """
 
-    pixels = len(pixel_neighbors)
+    pixels = len(neighbors)
 
     regularization_matrix = np.zeros(shape=(pixels, pixels))
 
-    regularization_coefficient = coefficient ** 2.0
+    regularization_coefficient = coefficient**2.0
+    regularization_coefficient_zeroth = coefficient_zeroth**2.0
 
     for i in range(pixels):
         regularization_matrix[i, i] += 1e-8
-        for j in range(pixel_neighbors_sizes[i]):
-            neighbor_index = pixel_neighbors[i, j]
+        regularization_matrix[i, i] += regularization_coefficient_zeroth
+        for j in range(neighbors_sizes[i]):
+            neighbor_index = neighbors[i, j]
             regularization_matrix[i, i] += regularization_coefficient
             regularization_matrix[i, neighbor_index] -= regularization_coefficient
 
@@ -59,13 +141,16 @@ def adaptive_regularization_weights_from(
     Two regularization coefficients are used, corresponding to the:
 
     1) (pixel_signals) - pixels with a high pixel-signal (i.e. where the signal is located in the pixelization).
-    2) (1.0 - pixel_signals) - pixels with a low pixel-signal (i.e. where the signal is not located in the
-     pixelization).
+    2) (1.0 - pixel_signals) - pixels with a low pixel-signal (i.e. where the signal is not located in the pixelization).
 
     Parameters
     ----------
-    coefficients
-        The regularization coefficients which controls the degree of smoothing of the inversion reconstruction.
+    inner_coefficient
+        The inner regularization coefficients which controls the degree of smoothing of the inversion reconstruction
+        in the inner regions of a mesh's reconstruction.
+    outer_coefficient
+        The outer regularization coefficients which controls the degree of smoothing of the inversion reconstruction
+        in the outer regions of a mesh's reconstruction.
     pixel_signals
         The estimated signal in every pixelization pixel, used to change the regularization weighting of high signal
         and low signal pixelizations.
@@ -84,8 +169,8 @@ def adaptive_regularization_weights_from(
 @numba_util.jit()
 def weighted_regularization_matrix_from(
     regularization_weights: np.ndarray,
-    pixel_neighbors: np.ndarray,
-    pixel_neighbors_sizes: np.ndarray,
+    neighbors: np.ndarray,
+    neighbors_sizes: np.ndarray,
 ) -> np.ndarray:
     """
     From the pixel-neighbors, setup the regularization matrix using the weighted regularization scheme.
@@ -94,10 +179,10 @@ def weighted_regularization_matrix_from(
     ----------
     regularization_weights
         The regularization_ weight of each pixel, which governs how much smoothing is applied to that individual pixel.
-    pixel_neighbors
+    neighbors
         An array of length (total_pixels) which provides the index of all neighbors of every pixel in
         the Voronoi grid (entries of -1 correspond to no neighbor).
-    pixel_neighbors_sizes
+    neighbors_sizes
         An array of length (total_pixels) which gives the number of neighbors of every pixel in the
         Voronoi grid.
 
@@ -108,16 +193,16 @@ def weighted_regularization_matrix_from(
         coefficient of every source pixel is different.
     """
 
-    pixels = len(regularization_weights)
+    parameters = len(regularization_weights)
 
-    regularization_matrix = np.zeros(shape=(pixels, pixels))
+    regularization_matrix = np.zeros(shape=(parameters, parameters))
 
-    regularization_weight = regularization_weights ** 2.0
+    regularization_weight = regularization_weights**2.0
 
-    for i in range(pixels):
+    for i in range(parameters):
         regularization_matrix[i, i] += 1e-8
-        for j in range(pixel_neighbors_sizes[i]):
-            neighbor_index = pixel_neighbors[i, j]
+        for j in range(neighbors_sizes[i]):
+            neighbor_index = neighbors[i, j]
             regularization_matrix[i, i] += regularization_weight[neighbor_index]
             regularization_matrix[
                 neighbor_index, neighbor_index
@@ -185,8 +270,8 @@ def reg_split_from(
                 flag = 1
 
             if j >= max_j:
-                raise exc.PixelizationException(
-                    "the number of Voronoi natural neighbours exceeds 100."
+                raise exc.MeshException(
+                    f"The number of Voronoi natural neighbours exceeds {max_j}."
                 )
 
         if flag == 0:
@@ -209,13 +294,13 @@ def pixel_splitted_regularization_matrix_from(
     # Currently, I simply mulitply the i-th weight to the i-th source pixel, but there should be different ways.
     # Need to keep an eye here.
 
-    pixels = int(len(splitted_mappings) / 4)
+    parameters = int(len(splitted_mappings) / 4)
 
-    regularization_matrix = np.zeros(shape=(pixels, pixels))
+    regularization_matrix = np.zeros(shape=(parameters, parameters))
 
-    regularization_weight = regularization_weights ** 2.0
+    regularization_weight = regularization_weights**2.0
 
-    for i in range(pixels):
+    for i in range(parameters):
 
         regularization_matrix[i, i] += 2e-8
 
@@ -236,7 +321,7 @@ def pixel_splitted_regularization_matrix_from(
                         weight[l] * weight[l + m] * regularization_weight[i]
                     )
 
-    for i in range(pixels):
+    for i in range(parameters):
         regularization_matrix[i, i] /= 2.0
 
     return regularization_matrix
