@@ -1,20 +1,22 @@
 from autoarray.dataset.mock.mock_dataset import MockDataset
-from autoarray.inversion.mock.mock_pixelization import MockPixelization
+from autoarray.inversion.mock.mock_mesh import MockMesh
 from autoarray.inversion.mock.mock_regularization import MockRegularization
+from autoarray.inversion.mock.mock_pixelization import MockPixelization
 from autoarray.inversion.mock.mock_mapper import MockMapper
-from autoarray.inversion.mock.mock_linear_obj_func import MockLinearObjFunc
-from autoarray.inversion.mock.mock_leq import MockLEq
-from autoarray.inversion.mock.mock_leq_imaging import MockLEqImaging
-from autoarray.inversion.mock.mock_leq_interferometer import (
-    MockLEqInterferometerMapping,
-)
+from autoarray.inversion.mock.mock_linear_obj import MockLinearObj
+from autoarray.inversion.mock.mock_linear_obj_func_list import MockLinearObjFuncList
 from autoarray.inversion.mock.mock_inversion import MockInversion
+from autoarray.inversion.mock.mock_inversion_imaging import MockInversionImaging
+from autoarray.inversion.mock.mock_inversion_imaging import MockInversionImagingWTilde
+from autoarray.inversion.mock.mock_inversion_interferometer import (
+    MockInversionInterferometer,
+)
 from autoarray.fit.mock.mock_fit_imaging import MockFitImaging
 from autoarray.fit.mock.mock_fit_interferometer import MockFitInterferometer
 from autoarray.mask.mock.mock_mask import MockMask
 from autoarray.operators.mock.mock_convolver import MockConvolver
-from autoarray.structures.mock.mock_grid import MockGrid2DPixelization
-from autoarray.structures.mock.mock_grid import MockPixelizationGrid
+from autoarray.structures.mock.mock_grid import MockGrid2DMesh
+from autoarray.structures.mock.mock_grid import MockMeshGrid
 from autoarray.structures.mock.mock_structure_decorators import MockGridRadialMinimum
 from autoarray.structures.mock.mock_structure_decorators import MockGrid1DLikeObj
 from autoarray.structures.mock.mock_structure_decorators import MockGrid2DLikeObj
