@@ -37,8 +37,8 @@ class Convolver:
         This calculation also accounts for the blurring of light outside of the masked regions which blurs into \
         the masked region.
 
-        IMAGE FRAMES:
-        -------------
+
+        **IMAGE FRAMES:**
 
         For a masked in 2D, one can compute for every pixel all of the unmasked pixels it will blur light into for \
         a given PSF kernel size, e.g.:
@@ -104,8 +104,8 @@ class Convolver:
         Once we have set up all these quantities, the convolution routine simply uses them to convolve a 1D array of a
         masked or the masked of a util in the inversion module.
 
-        BLURRING FRAMES:
-        ---------------
+
+        **BLURRING FRAMES:**
 
         Whilst the scheme above accounts for all blurred light within the masks, it does not account for the fact that \
         pixels outside of the masks will also blur light into it. This effect is accounted for using blurring frames.
@@ -313,7 +313,7 @@ class Convolver:
         For a given 1D array and blurring array, convolve the two using this convolver.
 
         Parameters
-        -----------
+        ----------
         image
             1D array of the values which are to be blurred with the convolver's PSF.
         blurring_image
@@ -337,7 +337,7 @@ class Convolver:
             blurring_frame_1d_lengths=self.blurring_frame_1d_lengths,
         )
 
-        return Array2D(array=convolved_image, mask=self.mask.mask_sub_1)
+        return Array2D(values=convolved_image, mask=self.mask.derive_mask.sub_1)
 
     @staticmethod
     @numba_util.jit()
@@ -385,7 +385,7 @@ class Convolver:
         """For a given 1D array and blurring array, convolve the two using this convolver.
 
         Parameters
-        -----------
+        ----------
         image
             1D array of the values which are to be blurred with the convolver's PSF.
         blurring_image
@@ -399,13 +399,13 @@ class Convolver:
             image_frame_1d_lengths=self.image_frame_1d_lengths,
         )
 
-        return Array2D(array=convolved_image, mask=self.mask.mask_sub_1)
+        return Array2D(values=convolved_image, mask=self.mask.derive_mask.sub_1)
 
     def convolve_image_no_blurring_interpolation(self, image):
         """For a given 1D array and blurring array, convolve the two using this convolver.
 
         Parameters
-        -----------
+        ----------
         image
             1D array of the values which are to be blurred with the convolver's PSF.
         blurring_image
@@ -419,7 +419,7 @@ class Convolver:
             image_frame_1d_lengths=self.image_frame_1d_lengths,
         )
 
-        return Array2D(array=convolved_image, mask=self.mask.mask_sub_1)
+        return Array2D(values=convolved_image, mask=self.mask.derive_mask.sub_1)
 
     @staticmethod
     @numba_util.jit()
@@ -514,7 +514,7 @@ class Convolver:
         identical fashion to above.
 
         Parameters
-        -----------
+        ----------
         mapping_matrix
             The 2D mapping matrix describing how every inversion pixel maps to a pixel on the data pixel.
         """
