@@ -1,7 +1,6 @@
 from astropy import units
 import numpy as np
 import scipy.signal
-from skimage.transform import resize, rescale
 from typing import List, Tuple, Union
 
 from autoarray.mask.mask_2d import Mask2D
@@ -17,26 +16,35 @@ from autoarray.structures.arrays import array_2d_util
 
 class Kernel2D(AbstractArray2D):
     def __new__(
-        cls, array, mask, header=None, normalize: bool = False, *args, **kwargs
+        cls,
+        values,
+        mask,
+        header=None,
+        normalize: bool = False,
+        store_native: bool = False,
+        *args,
+        **kwargs
     ):
         """
         An array of values, which are paired to a uniform 2D mask of pixels and sub-pixels. Each entry
-        on the array corresponds to a value at the centre of a sub-pixel in an unmasked pixel. See the *Array2D* class
+        on the array corresponds to a value at the centre of a sub-pixel in an unmasked pixel. See the ``Array2D`` class
         for a full description of how Arrays work.
 
-        The *Kernel2D* class is an *Array2D* but with additioonal methods that allow it to be convolved with data.
+        The ``Kernel2D`` class is an ``Array2D`` but with additioonal methods that allow it to be convolved with data.
 
         Parameters
         ----------
-        array
+        values
             The values of the array.
-        mask :Mask2D
+        mask
             The 2D mask associated with the array, defining the pixels each array value is paired with and
             originates from.
         normalize
             If True, the Kernel2D's array values are normalized such that they sum to 1.0.
         """
-        obj = super().__new__(cls=cls, array=array, mask=mask, header=header)
+        obj = super().__new__(
+            cls=cls, values=values, mask=mask, header=header, store_native=store_native
+        )
 
         if normalize:
             obj[:] = np.divide(obj, np.sum(obj))
@@ -44,96 +52,11 @@ class Kernel2D(AbstractArray2D):
         return obj
 
     @classmethod
-    def manual_slim(
+    def no_mask(
         cls,
-        array: Union[np.ndarray, List],
-        shape_native: Tuple[int, int],
-        pixel_scales: ty.PixelScales,
-        origin: Tuple[float, float] = (0.0, 0.0),
-        normalize: bool = False,
-    ):
-        """
-        Create a Kernel2D (see *Kernel2D.__new__*) by inputting the kernel values in 1D, for example:
-
-        kernel=np.array([1.0, 2.0, 3.0, 4.0])
-
-        kernel=[1.0, 2.0, 3.0, 4.0]
-
-        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_native must be
-        input into this method. The mask is setup as a unmasked `Mask2D` of shape_native.
-
-        Parameters
-        ----------
-        array or list
-            The values of the array input as an ndarray of shape [total_unmasked_pixels*(sub_size**2)] or a list of
-            lists.
-        shape_native
-            The 2D shape of the mask the array is paired with.
-        pixel_scales
-            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
-            it is converted to a (float, float) structure.
-        sub_size
-            The size (sub_size x sub_size) of each unmasked pixels sub-array.
-        origin
-            The (y,x) scaled units origin of the mask's coordinate system.
-        normalize
-            If True, the Kernel2D's array values are normalized such that they sum to 1.0.
-        """
-        array = Array2D.manual_slim(
-            array=array,
-            shape_native=shape_native,
-            pixel_scales=pixel_scales,
-            origin=origin,
-        )
-
-        return Kernel2D(array=array, mask=array.mask, normalize=normalize)
-
-    @classmethod
-    def manual_native(
-        cls,
-        array: Union[np.ndarray, List],
-        pixel_scales: ty.PixelScales,
-        origin: Tuple[float, float] = (0.0, 0.0),
-        normalize: bool = False,
-    ) -> "Kernel2D":
-        """
-        Create an Kernel2D (see *Kernel2D.__new__*) by inputting the kernel values in 2D, for example:
-
-        kernel=np.ndarray([[1.0, 2.0], [3.0, 4.0]])
-
-        kernel=[[1.0, 2.0],
-              [3.0, 4.0]]
-
-        The 2D shape of the array and its mask are determined from the input array and the mask is setup as an
-        unmasked `Mask2D` of shape_native.
-
-        Parameters
-        ----------
-        array or list
-            The values of the array input as an ndarray of shape [total_y_pixels*sub_size, total_x_pixel*sub_size] or a
-             list of lists.
-        pixel_scales
-            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
-            it is converted to a (float, float) structure.
-        sub_size
-            The size (sub_size x sub_size) of each unmasked pixels sub-array.
-        origin
-            The (y,x) scaled units origin of the mask's coordinate system.
-        normalize
-            If True, the Kernel2D's array values are normalized such that they sum to 1.0.
-        """
-        array = Array2D.manual_native(
-            array=array, pixel_scales=pixel_scales, origin=origin
-        )
-
-        return Kernel2D(array=array, mask=array.mask, normalize=normalize)
-
-    @classmethod
-    def manual(
-        cls,
-        array: Union[np.ndarray, List],
-        shape_native: Tuple[int, int],
+        values: Union[np.ndarray, List],
         pixel_scales: ty.PixelScales,
+        shape_native: Tuple[int, int] = None,
         origin: Tuple[float, float] = (0.0, 0.0),
         normalize: bool = False,
     ):
@@ -144,7 +67,7 @@ class Kernel2D(AbstractArray2D):
         See the manual_slim and manual_native methods for examples.
         Parameters
         ----------
-        array or list
+        values
             The values of the array input as an ndarray of shape [total_unmasked_pixels*(sub_size**2)] or a list of
             lists.
         shape_native
@@ -159,17 +82,13 @@ class Kernel2D(AbstractArray2D):
         normalize
             If True, the Kernel2D's array values are normalized such that they sum to 1.0.
         """
-        if len(array.shape) == 1:
-            return cls.manual_slim(
-                array=array,
-                shape_native=shape_native,
-                pixel_scales=pixel_scales,
-                origin=origin,
-                normalize=normalize,
-            )
-        return cls.manual_native(
-            array=array, pixel_scales=pixel_scales, origin=origin, normalize=normalize
+        values = Array2D.no_mask(
+            values=values,
+            shape_native=shape_native,
+            pixel_scales=pixel_scales,
+            origin=origin,
         )
+        return Kernel2D(values=values, mask=values.mask, normalize=normalize)
 
     @classmethod
     def full(
@@ -203,8 +122,8 @@ class Kernel2D(AbstractArray2D):
         normalize
             If True, the Kernel2D's array values are normalized such that they sum to 1.0.
         """
-        return Kernel2D.manual_native(
-            array=np.full(fill_value=fill_value, shape=shape_native),
+        return Kernel2D.no_mask(
+            values=np.full(fill_value=fill_value, shape=shape_native),
             pixel_scales=pixel_scales,
             origin=origin,
             normalize=normalize,
@@ -299,7 +218,7 @@ class Kernel2D(AbstractArray2D):
 
         array = np.array([[0.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.0, 0.0, 0.0]])
 
-        return cls.manual_native(array=array, pixel_scales=pixel_scales)
+        return cls.no_mask(values=array, pixel_scales=pixel_scales)
 
     @classmethod
     def from_gaussian(
@@ -339,7 +258,7 @@ class Kernel2D(AbstractArray2D):
 
         grid = Grid2D.uniform(shape_native=shape_native, pixel_scales=pixel_scales)
         grid_shifted = np.subtract(grid, centre)
-        grid_radius = np.sqrt(np.sum(grid_shifted ** 2.0, 1))
+        grid_radius = np.sqrt(np.sum(grid_shifted**2.0, 1))
         theta_coordinate_to_profile = np.arctan2(
             grid_shifted[:, 0], grid_shifted[:, 1]
         ) - np.radians(angle)
@@ -362,8 +281,8 @@ class Kernel2D(AbstractArray2D):
             np.exp(-0.5 * np.square(np.divide(grid_elliptical_radii, sigma))),
         )
 
-        return cls.manual_slim(
-            array=gaussian,
+        return cls.no_mask(
+            values=gaussian,
             shape_native=shape_native,
             pixel_scales=pixel_scales,
             normalize=normalize,
@@ -436,7 +355,7 @@ class Kernel2D(AbstractArray2D):
         header_hdu_obj = array_2d_util.header_obj_from(file_path=file_path, hdu=hdu)
 
         return Kernel2D(
-            array=array[:],
+            values=array[:],
             mask=array.mask,
             normalize=normalize,
             header=Header(header_sci_obj=header_sci_obj, header_hdu_obj=header_hdu_obj),
@@ -465,6 +384,8 @@ class Kernel2D(AbstractArray2D):
             Whether the PSF should be normalized after being rescaled.
         """
 
+        from skimage.transform import resize, rescale
+
         kernel_rescaled = rescale(
             self.native,
             rescale_factor,
@@ -519,8 +440,8 @@ class Kernel2D(AbstractArray2D):
 
             pixel_scales = None
 
-        return Kernel2D.manual_native(
-            array=kernel_rescaled, pixel_scales=pixel_scales, normalize=normalize
+        return Kernel2D.no_mask(
+            values=kernel_rescaled, pixel_scales=pixel_scales, normalize=normalize
         )
 
     @property
@@ -528,7 +449,7 @@ class Kernel2D(AbstractArray2D):
         """
         Normalize the Kernel2D such that its data_vector values sum to unity.
         """
-        return Kernel2D(array=self, mask=self.mask, normalize=True)
+        return Kernel2D(values=self, mask=self.mask, normalize=True)
 
     def convolved_array_from(self, array: Array2D) -> Array2D:
         """
@@ -561,7 +482,7 @@ class Kernel2D(AbstractArray2D):
             mask_2d=array_binned_2d.mask, array_2d_native=convolved_array_2d, sub_size=1
         )
 
-        return Array2D(array=convolved_array_1d, mask=array_binned_2d.mask)
+        return Array2D(values=convolved_array_1d, mask=array_binned_2d.mask)
 
     def convolved_array_with_mask_from(self, array: Array2D, mask: Mask2D) -> Array2D:
         """
@@ -591,4 +512,4 @@ class Kernel2D(AbstractArray2D):
             mask_2d=mask, array_2d_native=convolved_array_2d, sub_size=1
         )
 
-        return Array2D(array=convolved_array_1d, mask=mask.mask_sub_1)
+        return Array2D(values=convolved_array_1d, mask=mask.derive_mask.sub_1)
