@@ -1,13 +1,13 @@
 import numpy as np
 import os
 from os import path
-import pickle
 from typing import List, Optional, Tuple, Union
 import json
 
 from autoarray.abstract_ndarray import AbstractNDArray
+from autoarray.geometry.geometry_2d_irregular import Geometry2DIrregular
 from autoarray.mask.mask_2d import Mask2D
-from autoarray.structures.values import ValuesIrregular
+from autoarray.structures.arrays.irregular import ArrayIrregular
 
 from autoarray import exc
 from autoarray.structures.grids import grid_2d_util
@@ -15,7 +15,7 @@ from autoarray.geometry import geometry_util
 
 
 class Grid2DIrregular(AbstractNDArray):
-    def __new__(cls, grid: Union[np.ndarray, List]):
+    def __new__(cls, values: Union[np.ndarray, List]):
         """
         An irregular grid of (y,x) coordinates.
 
@@ -27,71 +27,58 @@ class Grid2DIrregular(AbstractNDArray):
         The coordinates input to this function can have any of the following forms (they will be converted to the
         1D NumPy array structure and can be converted back using the object's properties):
 
-        [(y0,x0), (y1,x1)]
-        [[y0,x0], [y1,x1]]
+        ::
+
+            [(y0,x0), (y1,x1)]
+            [[y0,x0], [y1,x1]]
 
         If your grid lies on a 2D uniform grid of data the `Grid2D` data structure should be used.
 
         Parameters
         ----------
-        grid : Grid2DIrregular
+        values
             The irregular grid of (y,x) coordinates.
         """
 
-        if len(grid) == 0:
+        if len(values) == 0:
             return []
 
-        if type(grid) is list:
+        if type(values) is list:
 
-            if isinstance(grid[0], Grid2DIrregular):
-                return grid
+            if isinstance(values[0], Grid2DIrregular):
+                return values
 
-            grid = np.asarray(grid)
+            values = np.asarray(values)
 
-        obj = grid.view(cls)
+        obj = values.view(cls)
 
         return obj
 
     @property
-    def shape_native_scaled(self) -> Tuple[float, float]:
+    def geometry(self):
         """
         The (y,x) 2D shape of the irregular grid in scaled units, computed by taking the minimum and
         maximum values of (y,x) coordinates on the grid.
         """
-        return (
+        shape_native_scaled = (
             np.amax(self[:, 0]).astype("float") - np.amin(self[:, 0]).astype("float"),
             np.amax(self[:, 1]).astype("float") - np.amin(self[:, 1]).astype("float"),
         )
 
-    @property
-    def scaled_maxima(self) -> Tuple[int, int]:
-        """The maximum values of the coordinates returned as a tuple (y_max, x_max)."""
-        return (
+        scaled_maxima = (
             np.amax(self[:, 0]).astype("float"),
             np.amax(self[:, 1]).astype("float"),
         )
 
-    @property
-    def scaled_minima(self) -> Tuple[int, int]:
-        """The minimum values of the coordinates returned as a tuple (y_max, x_max)."""
-        return (
+        scaled_minima = (
             np.amin(self[:, 0]).astype("float"),
             np.amin(self[:, 1]).astype("float"),
         )
 
-    @property
-    def extent(self) -> np.ndarray:
-        """The extent of the coordinates returned as a NumPy array [x_min, x_max, y_min, y_max].
-
-        This follows the format of the extent input parameter in the matplotlib method imshow (and other methods) and
-        is used for visualization in the plot module."""
-        return np.array(
-            [
-                self.scaled_minima[1],
-                self.scaled_maxima[1],
-                self.scaled_minima[0],
-                self.scaled_maxima[0],
-            ]
+        return Geometry2DIrregular(
+            shape_native_scaled=shape_native_scaled,
+            scaled_maxima=scaled_maxima,
+            scaled_minima=scaled_minima,
         )
 
     @property
@@ -107,23 +94,25 @@ class Grid2DIrregular(AbstractNDArray):
         """
         Create `Grid2DIrregular` from a list of y and x values.
         """
-        return Grid2DIrregular(grid=np.stack((y, x), axis=-1))
+        return Grid2DIrregular(values=np.stack((y, x), axis=-1))
 
     @classmethod
     def from_pixels_and_mask(
         cls, pixels: Union[np.ndarray, List], mask: Mask2D
     ) -> "Grid2DIrregular":
         """
-        Create `Grid2DIrregular` from a list of coordinates in pixel units and a mask which allows these coordinates to
-        be converted to scaled units.
+        Create `Grid2DIrregular` from a list of coordinates in pixel units and a mask which allows these
+        coordinates to be converted to scaled units.
         """
 
         coorindates = [
-            mask.scaled_coordinates_2d_from(pixel_coordinates_2d=pixel_coordinates_2d)
+            mask.geometry.scaled_coordinates_2d_from(
+                pixel_coordinates_2d=pixel_coordinates_2d
+            )
             for pixel_coordinates_2d in pixels
         ]
 
-        return Grid2DIrregular(grid=coorindates)
+        return Grid2DIrregular(values=coorindates)
 
     @property
     def in_list(self) -> List:
@@ -132,14 +121,14 @@ class Grid2DIrregular(AbstractNDArray):
         """
         return [tuple(value) for value in self]
 
-    def values_from(self, array_slim: np.ndarray) -> ValuesIrregular:
+    def values_from(self, array_slim: np.ndarray) -> ArrayIrregular:
         """
-        Create a *ValuesIrregular* object from a 1D NumPy array of values of shape [total_coordinates]. The
-        *ValuesIrregular* are structured following this `Grid2DIrregular` instance.
+        Create a *ArrayIrregular* object from a 1D NumPy array of values of shape [total_coordinates], which
+        are structured following this `Grid2DIrregular` instance.
         """
-        return ValuesIrregular(values=array_slim)
+        return ArrayIrregular(values=array_slim)
 
-    def values_via_value_from(self, value: float) -> ValuesIrregular:
+    def values_via_value_from(self, value: float) -> ArrayIrregular:
         return self.values_from(
             array_slim=np.full(fill_value=value, shape=self.shape[0])
         )
@@ -148,42 +137,43 @@ class Grid2DIrregular(AbstractNDArray):
         self, grid_slim: np.ndarray
     ) -> Union["Grid2DIrregular", "Grid2DIrregularTransformed"]:
         """
-        Create a `Grid2DIrregular` object from a 2D NumPy array of values of shape [total_coordinates, 2]. The
-        `Grid2DIrregular` are structured following this *Grid2DIrregular* instance."""
+        Create a `Grid2DIrregular` object from a 2D NumPy array of values of shape [total_coordinates, 2],
+        which are structured following this *Grid2DIrregular* instance.
+        """
 
         from autoarray.structures.grids.transformed_2d import Grid2DTransformedNumpy
 
         if isinstance(grid_slim, Grid2DTransformedNumpy):
-            return Grid2DIrregularTransformed(grid=grid_slim)
-        return Grid2DIrregular(grid=grid_slim)
+            return Grid2DIrregularTransformed(values=grid_slim)
+        return Grid2DIrregular(values=grid_slim)
 
     def grid_2d_via_deflection_grid_from(
         self, deflection_grid: np.ndarray
     ) -> "Grid2DIrregular":
         """
         Returns a new Grid2DIrregular from this grid coordinates, where the (y,x) coordinates of this grid have a
-            grid of (y,x) values, termed the deflection grid, subtracted from them to determine the new grid of (y,x)
-            values.
+        grid of (y,x) values, termed the deflection grid, subtracted from them to determine the new grid of (y,x)
+        values.
 
-            This is used by PyAutoLens to perform grid ray-tracing.
+        This is used by **PyAutoLens** to perform grid ray-tracing.
 
-            Parameters
-            ----------
-            deflection_grid
-                The grid of (y,x) coordinates which is subtracted from this grid.
+        Parameters
+        ----------
+        deflection_grid
+            The grid of (y,x) coordinates which is subtracted from this grid.
         """
-        return Grid2DIrregular(grid=self - deflection_grid)
+        return Grid2DIrregular(values=self - deflection_grid)
 
     def structure_2d_from(
         self, result: Union[np.ndarray, List]
-    ) -> Union[ValuesIrregular, "Grid2DIrregular", "Grid2DIrregularTransformed", List]:
+    ) -> Union[ArrayIrregular, "Grid2DIrregular", "Grid2DIrregularTransformed", List]:
         """
-        Convert a result from a non autoarray structure to an aa.ValuesIrregular or aa.Grid2DIrregular structure, where
+        Convert a result from a non autoarray structure to an aa.ArrayIrregular or aa.Grid2DIrregular structure, where
         the conversion depends on type(result) as follows:
 
-        - 1D np.ndarray   -> aa.ValuesIrregular
+        - 1D np.ndarray   -> aa.ArrayIrregular
         - 2D np.ndarray   -> aa.Grid2DIrregular
-        - [1D np.ndarray] -> [aa.ValuesIrregular]
+        - [1D np.ndarray] -> [aa.ArrayIrregular]
         - [2D np.ndarray] -> [aa.Grid2DIrregular]
 
         This function is used by the grid_2d_to_structure decorator to convert the output result of a function
@@ -191,7 +181,7 @@ class Grid2DIrregular(AbstractNDArray):
 
         Parameters
         ----------
-        result or [np.ndarray]
+        result
             The input result (e.g. of a decorated function) that is converted to a PyAutoArray structure.
         """
 
@@ -208,20 +198,22 @@ class Grid2DIrregular(AbstractNDArray):
 
     def structure_2d_list_from(
         self, result_list: List
-    ) -> List[Union[ValuesIrregular, "Grid2DIrregular", "Grid2DIrregularTransformed"]]:
+    ) -> List[Union[ArrayIrregular, "Grid2DIrregular", "Grid2DIrregularTransformed"]]:
         """
-        Convert a result from a list of non autoarray structures to a list of aa.ValuesIrregular or aa.Grid2DIrregular
+        Convert a result from a list of non autoarray structures to a list of aa.ArrayIrregular or aa.Grid2DIrregular
         structures, where the conversion depends on type(result) as follows:
 
-        - [1D np.ndarray] -> [aa.ValuesIrregular]
-        - [2D np.ndarray] -> [aa.Grid2DIrregular]
+        ::
+
+            - [1D np.ndarray] -> [aa.ArrayIrregular]
+            - [2D np.ndarray] -> [aa.Grid2DIrregular]
 
         This function is used by the grid_like_list_to_structure_list decorator to convert the output result of a
         function to a list of autoarray structure when a `Grid2DIrregular` instance is passed to the decorated function.
 
         Parameters
         ----------
-        result_list or [np.ndarray]
+        result_list
             The input result (e.g. of a decorated function) that is converted to a PyAutoArray structure.
         """
         if len(result_list[0].shape) == 1:
@@ -231,7 +223,7 @@ class Grid2DIrregular(AbstractNDArray):
 
     def squared_distances_to_coordinate_from(
         self, coordinate: Tuple[float, float] = (0.0, 0.0)
-    ) -> ValuesIrregular:
+    ) -> ArrayIrregular:
         """
         Returns the squared distance of every (y,x) coordinate in this *Coordinate* instance from an input
         coordinate.
@@ -248,14 +240,14 @@ class Grid2DIrregular(AbstractNDArray):
 
     def distances_to_coordinate_from(
         self, coordinate: Tuple[float, float] = (0.0, 0.0)
-    ) -> ValuesIrregular:
+    ) -> ArrayIrregular:
         """
         Returns the distance of every (y,x) coordinate in this *Coordinate* instance from an input coordinate.
 
-            Parameters
-            ----------
-            coordinate
-                The (y,x) coordinate from which the distance of every *Coordinate* is computed.
+        Parameters
+        ----------
+        coordinate
+            The (y,x) coordinate from which the distance of every coordinate is computed.
         """
         distances = np.sqrt(
             self.squared_distances_to_coordinate_from(coordinate=coordinate)
@@ -263,22 +255,26 @@ class Grid2DIrregular(AbstractNDArray):
         return self.values_from(array_slim=distances)
 
     @property
-    def furthest_distances_to_other_coordinates(self) -> ValuesIrregular:
+    def furthest_distances_to_other_coordinates(self) -> ArrayIrregular:
         """
         For every (y,x) coordinate on the `Grid2DIrregular` returns the furthest radial distance of each coordinate
         to any other coordinate on the grid.
 
         For example, for the following grid:
 
-        grid=[(0.0, 0.0), (0.0, 1.0), (0.0, 3.0)]
+        ::
+
+            values=[(0.0, 0.0), (0.0, 1.0), (0.0, 3.0)]
 
         The returned further distances are:
 
-        [3.0, 2.0, 3.0]
+        ::
+
+            [3.0, 2.0, 3.0]
 
         Returns
         -------
-        ValuesIrregular
+        ArrayIrregular
             The further distances of every coordinate to every other coordinate on the irregular grid.
         """
 
@@ -293,9 +289,7 @@ class Grid2DIrregular(AbstractNDArray):
 
         return self.values_from(array_slim=radial_distances_max)
 
-    def grid_of_closest_from(
-        self, grid_pair: Union["Grid2DIrregular"]
-    ) -> "Grid2DIrregular":
+    def grid_of_closest_from(self, grid_pair: "Grid2DIrregular") -> "Grid2DIrregular":
         """
         From an input grid, find the closest coordinates of this instance of the `Grid2DIrregular` to each coordinate
         on the input grid and return each closest coordinate as a new `Grid2DIrregular`.
@@ -307,10 +301,8 @@ class Grid2DIrregular(AbstractNDArray):
 
         Returns
         -------
-        Grid2DIrregular
-            The grid of coordinates corresponding to the closest coordinate of each coordinate of this instance of
-            the `Grid2DIrregular` to the input grid.
-
+        The grid of coordinates corresponding to the closest coordinate of each coordinate of this instance of
+        the `Grid2DIrregular` to the input grid.
         """
 
         grid_of_closest = np.zeros((grid_pair.shape[0], 2))
@@ -324,12 +316,12 @@ class Grid2DIrregular(AbstractNDArray):
 
             grid_of_closest[i, :] = self[np.argmin(radial_distances), :]
 
-        return Grid2DIrregular(grid=grid_of_closest)
+        return Grid2DIrregular(values=grid_of_closest)
 
     @classmethod
     def from_json(cls, file_path: str) -> "Grid2DIrregular":
         """
-        Create a `Grid2DIrregular` object from a file which stores the coordinates as a list of list of tuples.
+        Returns a `Grid2DIrregular` object from a .json file, which stores the coordinates as a list of list of tuples.
 
         Parameters
         ----------
@@ -340,11 +332,11 @@ class Grid2DIrregular(AbstractNDArray):
         with open(file_path) as infile:
             grid = json.load(infile)
 
-        return Grid2DIrregular(grid=grid)
+        return Grid2DIrregular(values=grid)
 
     def output_to_json(self, file_path: str, overwrite: bool = False):
         """
-        Output this instance of the `Grid2DIrregular` object to a list of list of tuples.
+        Output this instance of the `Grid2DIrregular` object to a .json file as a list of list of tuples.
 
         Parameters
         ----------
@@ -380,14 +372,16 @@ class Grid2DIrregularTransformed(Grid2DIrregular):
 class Grid2DIrregularUniform(Grid2DIrregular):
     def __new__(
         cls,
-        grid: np.ndarray,
+        values: np.ndarray,
         shape_native: Optional[Tuple[float, float]] = None,
         pixel_scales: Optional[Tuple[float, float]] = None,
     ):
         """
         A collection of (y,x) coordinates which is structured as follows:
 
-        [[x0, x1], [x0, x1]]
+        ::
+
+            [[x0, x1], [x0, x1]]
 
         The grid object does not store the coordinates as a list of tuples, but instead a 2D NumPy array of
         shape [total_coordinates, 2]. They are stored as a NumPy array so the coordinates can be used efficiently for
@@ -395,7 +389,9 @@ class Grid2DIrregularUniform(Grid2DIrregular):
 
         The coordinates input to this function can have any of the following forms:
 
-        [(y0,x0), (y1,x1)]
+        ::
+
+            [(y0,x0), (y1,x1)]
 
         In all cases, they will be converted to a list of tuples followed by a 2D NumPy array.
 
@@ -409,30 +405,28 @@ class Grid2DIrregularUniform(Grid2DIrregular):
 
         Parameters
         ----------
-        grid : [tuple] or equivalent
+        values
             A collection of (y,x) coordinates that.
         """
 
-        #    obj = super(Grid2DIrregularUniform, cls).__new__(cls=cls, coordinates=coordinates)
-
-        if len(grid) == 0:
+        if len(values) == 0:
             return []
 
-        if isinstance(grid[0], float):
-            grid = [grid]
+        if isinstance(values[0], float):
+            values = [values]
 
-        if isinstance(grid[0], tuple):
-            grid = [grid]
-        elif isinstance(grid[0], np.ndarray):
-            if len(grid[0].shape) == 1:
-                grid = [grid]
-        elif isinstance(grid[0], list) and isinstance(grid[0][0], (float)):
-            grid = [grid]
+        if isinstance(values[0], tuple):
+            values = [values]
+        elif isinstance(values[0], np.ndarray):
+            if len(values[0].shape) == 1:
+                values = [values]
+        elif isinstance(values[0], list) and isinstance(values[0][0], (float)):
+            values = [values]
 
-        coordinates_arr = np.concatenate([np.array(i) for i in grid])
+        coordinates_arr = np.concatenate([np.array(i) for i in values])
 
         obj = coordinates_arr.view(cls)
-        obj._internal_list = grid
+        obj._internal_list = values
 
         pixel_scales = geometry_util.convert_pixel_scales_2d(pixel_scales=pixel_scales)
 
@@ -485,7 +479,9 @@ class Grid2DIrregularUniform(Grid2DIrregular):
         )
 
         return Grid2DIrregularUniform(
-            grid=grid_upscaled_1d, pixel_scales=pixel_scales, shape_native=shape_native
+            values=grid_upscaled_1d,
+            pixel_scales=pixel_scales,
+            shape_native=shape_native,
         )
 
     def grid_from(self, grid_slim: np.ndarray) -> "Grid2DIrregularUniform":
@@ -494,7 +490,7 @@ class Grid2DIrregularUniform(Grid2DIrregular):
         `Grid2DIrregularUniform` are structured following this *GridIrregular2D* instance.
         """
         return Grid2DIrregularUniform(
-            grid=grid_slim,
+            values=grid_slim,
             pixel_scales=self.pixel_scales,
             shape_native=self.shape_native,
         )
@@ -515,7 +511,7 @@ class Grid2DIrregularUniform(Grid2DIrregular):
             The grid of (y,x) coordinates which is subtracted from this grid.
         """
         return Grid2DIrregularUniform(
-            grid=self - deflection_grid,
+            values=self - deflection_grid,
             pixel_scales=self.pixel_scales,
             shape_native=self.shape_native,
         )
