@@ -1,8 +1,6 @@
 import numpy as np
 from typing import Callable, Union, List, Tuple, Optional
 
-from autoarray.structures.abstract_structure import Structure
-
 from autoarray.mask.mask_2d import Mask2D
 from autoarray.structures.grids.uniform_2d import Grid2D
 
@@ -26,20 +24,21 @@ def sub_steps_from(sub_steps):
 class Grid2DIterate(Grid2D):
     def __new__(
         cls,
-        grid: np.ndarray,
+        values: np.ndarray,
         mask: Mask2D,
         fractional_accuracy: float = 0.9999,
         relative_accuracy: Optional[float] = None,
         sub_steps: List[int] = None,
+        store_native: bool = False,
         *args,
         **kwargs
     ):
         """
-        Represents a grid of coordinates as described for the `Grid2D` class, but using an iterative sub-grid that
+        Represents a grid of coordinates as described for the ``Grid2D`` class, but using an iterative sub-grid that
         adapts its resolution when it is input into a function that performs an analytic calculation.
 
-        A `Grid2D` represents (y,x) coordinates using a sub-grid, where functions are evaluated once at every coordinate
-        on the sub-grid and averaged to give a more precise evaluation an analytic function. A `Grid2DIterate` does not
+        A ``Grid2D`` represents (y,x) coordinates using a sub-grid, where functions are evaluated once at every coordinate
+        on the sub-grid and averaged to give a more precise evaluation an analytic function. A ``Grid2DIterate`` does not
         have a specified sub-grid size, but instead iteratively recomputes the analytic function at increasing sub-grid
         sizes until an input fractional accuracy is reached.
 
@@ -48,15 +47,15 @@ class Grid2DIterate(Grid2D):
         fractional accuracy. For functions where a wide range of sub-grid sizes allow fractional accuracy to be met
         this ensures the function can be evaluated accurate in a computaionally efficient manner.
 
-        This overcomes a limitation of the `Grid2D` class whereby if a small subset of pixels require high levels of
+        This overcomes a limitation of the ``Grid2D`` class whereby if a small subset of pixels require high levels of
         sub-gridding to be evaluated accuracy, the entire grid would require this sub-grid size thus leading to
         unecessary expensive function evaluations.
 
         Parameters
         ----------
-        grid
+        values
             The (y,x) coordinates of the grid.
-        mask :Mask2D
+        mask
             The 2D mask associated with the grid, defining the pixels each grid coordinate is paired with and
             originates from.
         fractional_accuracy
@@ -67,16 +66,23 @@ class Grid2DIterate(Grid2D):
             The relative accuracy the function evaluted must meet to be accepted, where this value is the absolute
             difference of the values computed using the higher sub size and lower sub size grids. The relative
             accuracy depends on the units / magnitude of the function being evaluated.
-        sub_steps : [int] or None
+        sub_steps
             The sub-size values used to iteratively evaluated the function at high levels of sub-gridding. If None,
             they are setup as the default values [2, 4, 8, 16].
+        store_native
+            If True, the ndarray is stored in its native format [total_y_pixels, total_x_pixels, 2]. This avoids
+            mapping large data arrays to and from the slim / native formats, which can be a computational bottleneck.
         """
 
         sub_steps = sub_steps_from(sub_steps=sub_steps)
 
-        obj = grid.view(cls)
+        values = grid_2d_util.convert_grid_2d(
+            grid_2d=values, mask_2d=mask, store_native=store_native
+        )
+
+        obj = values.view(cls)
         obj.mask = mask
-        obj.grid = Grid2D.manual_mask(grid=np.asarray(obj), mask=mask)
+        obj.grid = Grid2D(values=np.asarray(obj), mask=mask, store_native=store_native)
         obj.fractional_accuracy = fractional_accuracy
         obj.relative_accuracy = relative_accuracy
         obj.sub_steps = sub_steps
@@ -100,9 +106,9 @@ class Grid2DIterate(Grid2D):
             self.sub_steps = obj.sub_steps
 
     @classmethod
-    def manual_slim(
+    def no_mask(
         cls,
-        grid: Union[np.ndarray, List],
+        values: Union[np.ndarray, List],
         shape_native: Tuple[int, int],
         pixel_scales: ty.PixelScales,
         origin: Tuple[float, float] = (0.0, 0.0),
@@ -118,11 +124,11 @@ class Grid2DIterate(Grid2D):
         grid=[[1.0, 1.0], [2.0, 2.0], [3.0, 3.0], [4.0, 4.0]]
 
         From 1D input the method cannot determine the 2D shape of the grid and its mask, thus the shape_native must be
-        input into this method. The mask is setup as a unmasked `Mask2D` of shape_native.
+        input into this method. The mask is setup as a unmasked ``Mask2D`` of shape_native.
 
         Parameters
         ----------
-        grid or list
+        values
             The (y,x) coordinates of the grid input as an ndarray of shape [total_unmasked_pixells*(sub_size**2), 2]
             or a list of lists.
         shape_native
@@ -144,10 +150,20 @@ class Grid2DIterate(Grid2D):
         origin
             The origin of the grid's mask.
         """
-        grid = grid_2d_util.convert_grid(grid=grid)
+
         pixel_scales = geometry_util.convert_pixel_scales_2d(pixel_scales=pixel_scales)
 
-        mask = Mask2D.unmasked(
+        values = grid_2d_util.convert_grid(grid=values)
+
+        if len(values.shape) == 2:
+
+            grid_2d_util.check_grid_slim(grid=values, shape_native=shape_native)
+
+        else:
+
+            shape_native = (int(values.shape[0]), int(values.shape[1]))
+
+        mask = Mask2D.all_false(
             shape_native=shape_native,
             pixel_scales=pixel_scales,
             sub_size=1,
@@ -155,7 +171,7 @@ class Grid2DIterate(Grid2D):
         )
 
         return Grid2DIterate(
-            grid=grid,
+            values=values,
             mask=mask,
             fractional_accuracy=fractional_accuracy,
             relative_accuracy=relative_accuracy,
@@ -207,8 +223,8 @@ class Grid2DIterate(Grid2D):
             origin=origin,
         )
 
-        return Grid2DIterate.manual_slim(
-            grid=grid_slim,
+        return Grid2DIterate.no_mask(
+            values=grid_slim,
             shape_native=shape_native,
             pixel_scales=pixel_scales,
             fractional_accuracy=fractional_accuracy,
@@ -253,8 +269,8 @@ class Grid2DIterate(Grid2D):
         )
 
         return Grid2DIterate(
-            grid=grid_slim,
-            mask=mask.mask_sub_1,
+            values=grid_slim,
+            mask=mask.derive_mask.sub_1,
             fractional_accuracy=fractional_accuracy,
             relative_accuracy=relative_accuracy,
             sub_steps=sub_steps,
@@ -297,7 +313,9 @@ class Grid2DIterate(Grid2D):
             they are setup as the default values [2, 4, 8, 16].
         """
 
-        blurring_mask = mask.blurring_mask_from(kernel_shape_native=kernel_shape_native)
+        blurring_mask = mask.derive_mask.blurring_from(
+            kernel_shape_native=kernel_shape_native
+        )
 
         return cls.from_mask(
             mask=blurring_mask,
@@ -309,14 +327,14 @@ class Grid2DIterate(Grid2D):
     @property
     def slim(self) -> "Grid2DIterate":
         """
-        Return a `Grid2D` where the data is stored its `slim` representation, which is an ndarray of shape
+        Return a ``Grid2D`` where the data is stored its ``slim`` representation, which is an ndarray of shape
         [total_unmasked_pixels * sub_size**2, 2].
 
-        If it is already stored in its `slim` representation  it is returned as it is. If not, it is  mapped from
-        `native` to `slim` and returned as a new `Grid2D`.
+        If it is already stored in its ``slim`` representation  it is returned as it is. If not, it is  mapped from
+        ``native`` to ``slim`` and returned as a new ``Grid2D``.
         """
         return Grid2DIterate(
-            grid=super().slim,
+            values=self,
             mask=self.mask,
             fractional_accuracy=self.fractional_accuracy,
             sub_steps=self.sub_steps,
@@ -325,25 +343,26 @@ class Grid2DIterate(Grid2D):
     @property
     def native(self) -> "Grid2DIterate":
         """
-        Return a `Grid2D` where the data is stored in its `native` representation, which has shape
+        Return a ``Grid2D`` where the data is stored in its ``native`` representation, which has shape
         [sub_size*total_y_pixels, sub_size*total_x_pixels, 2].
 
-        If it is already stored in its `native` representation it is return as it is. If not, it is mapped from
-        `slim` to `native` and returned as a new `Grid2D`.
+        If it is already stored in its ``native`` representation it is return as it is. If not, it is mapped from
+        ``slim`` to ``native`` and returned as a new ``Grid2D``.
 
-        This method is used in the child `Grid2D` classes to create their `native` properties.
+        This method is used in the child ``Grid2D`` classes to create their ``native`` properties.
         """
         return Grid2DIterate(
-            grid=super().native,
+            values=self,
             mask=self.mask,
             fractional_accuracy=self.fractional_accuracy,
             sub_steps=self.sub_steps,
+            store_native=True,
         )
 
     @property
     def binned(self) -> "Grid2DIterate":
         """
-        Return a `Grid2D` of the binned-up grid in its 1D representation, which is stored with
+        Return a ``Grid2D`` of the binned-up grid in its 1D representation, which is stored with
         shape [total_unmasked_pixels, 2].
 
         The binning up process converts a grid from (y,x) values where each value is a coordinate on the sub-grid to
@@ -353,8 +372,8 @@ class Grid2DIterate(Grid2D):
         If the grid is stored in 1D it is return as is. If it is stored in 2D, it must first be mapped from 2D to 1D.
         """
         return Grid2DIterate(
-            grid=super().binned,
-            mask=self.mask.mask_sub_1,
+            values=super().binned,
+            mask=self.mask.derive_mask.sub_1,
             fractional_accuracy=self.fractional_accuracy,
             sub_steps=self.sub_steps,
         )
@@ -374,7 +393,7 @@ class Grid2DIterate(Grid2D):
             The grid of (y,x) coordinates which is subtracted from this grid.
         """
         return Grid2DIterate(
-            grid=self - deflection_grid,
+            values=self - deflection_grid,
             mask=self.mask,
             fractional_accuracy=self.fractional_accuracy,
             sub_steps=self.sub_steps,
@@ -421,7 +440,7 @@ class Grid2DIterate(Grid2D):
             shape[1] + kernel_shape_native[1] - 1,
         )
 
-        padded_mask = Mask2D.unmasked(
+        padded_mask = Mask2D.all_false(
             shape_native=padded_shape,
             pixel_scales=self.mask.pixel_scales,
             sub_size=self.mask.sub_size,
@@ -456,9 +475,9 @@ class Grid2DIterate(Grid2D):
     ) -> Mask2D:
         """
         Returns a fractional mask from a result array, where the fractional mask describes whether the evaluated
-        value in the result array is within the `Grid2DIterate`'s specified fractional accuracy. The fractional mask thus
+        value in the result array is within the ``Grid2DIterate``'s specified fractional accuracy. The fractional mask thus
         determines whether a pixel on the grid needs to be reevaluated at a higher level of sub-gridding to meet the
-        specified fractional accuracy. If it must be re-evaluated, the fractional masks's entry is `False`.
+        specified fractional accuracy. If it must be re-evaluated, the fractional masks's entry is ``False``.
 
         The fractional mask is computed by comparing the results evaluated at one level of sub-gridding to another
         at a higher level of sub-griding. Thus, the sub-grid size in chosen on a per-pixel basis until the function
@@ -472,7 +491,7 @@ class Grid2DIterate(Grid2D):
             The results computed by a function using a higher sub-grid size.
         """
 
-        threshold_mask = Mask2D.unmasked(
+        threshold_mask = Mask2D.all_false(
             shape_native=array_lower_sub_2d.shape_native,
             pixel_scales=array_lower_sub_2d.pixel_scales,
             invert=True,
@@ -504,13 +523,13 @@ class Grid2DIterate(Grid2D):
         array_higher_mask: Mask2D,
     ) -> np.ndarray:
         """
-        Jitted functioon to determine the fractional mask, which is a mask where:
+        Jitted function to determine the fractional mask, which is a mask where:
 
-        - `True` entries signify the function has been evaluated in that pixel to desired accuracy and
-           therefore does not need to be iteratively computed at higher levels of sub-gridding.
+        - ``True`` entries signify the function has been evaluated in that pixel to desired accuracy and
+          therefore does not need to be iteratively computed at higher levels of sub-gridding.
 
-        - `False` entries signify the function has not been evaluated in that pixel to desired fractional accuracy and
-           therefore must be iterative computed at higher levels of sub-gridding to meet this accuracy.
+        - ``False`` entries signify the function has not been evaluated in that pixel to desired fractional accuracy and
+          therefore must be iterative computed at higher levels of sub-gridding to meet this accuracy.
         """
 
         if fractional_accuracy_threshold is not None:
@@ -567,7 +586,7 @@ class Grid2DIterate(Grid2D):
         return zeros. This occurs when a function is missing optional objects that contribute to the calculation.
 
         An example use case of this function is when a "image_2d_from" methods in **PyAutoGalaxy**'s
-        `LightProfile` module is comomputed, which by evaluating the function on a higher resolution sub-grids sample
+        ``LightProfile`` module is comomputed, which by evaluating the function on a higher resolution sub-grids sample
         the analytic light profile at more points and thus more precisely.
 
         Parameters
@@ -631,7 +650,7 @@ class Grid2DIterate(Grid2D):
 
     def return_iterated_array_result(self, iterated_array: Array2D) -> Array2D:
         """
-        Returns the resulting iterated array, by mapping it to 1D and then passing it back as an `Array2D` structure.
+        Returns the resulting iterated array, by mapping it to 1D and then passing it back as an ``Array2D`` structure.
 
         Parameters
         ----------
@@ -647,7 +666,7 @@ class Grid2DIterate(Grid2D):
             mask_2d=self.mask, array_2d_native=iterated_array, sub_size=1
         )
 
-        return Array2D(array=iterated_array_1d, mask=self.mask.mask_sub_1)
+        return Array2D(values=iterated_array_1d, mask=self.mask.derive_mask.sub_1)
 
     @staticmethod
     @numba_util.jit()
@@ -678,9 +697,9 @@ class Grid2DIterate(Grid2D):
     ) -> Mask2D:
         """
         Returns a fractional mask from a result array, where the fractional mask describes whether the evaluated
-        value in the result array is within the `Grid2DIterate`'s specified fractional accuracy. The fractional mask thus
+        value in the result array is within the ``Grid2DIterate``'s specified fractional accuracy. The fractional mask thus
         determines whether a pixel on the grid needs to be reevaluated at a higher level of sub-gridding to meet the
-        specified fractional accuracy. If it must be re-evaluated, the fractional masks's entry is `False`.
+        specified fractional accuracy. If it must be re-evaluated, the fractional masks's entry is ``False``.
 
         The fractional mask is computed by comparing the results evaluated at one level of sub-gridding to another
         at a higher level of sub-griding. Thus, the sub-grid size in chosen on a per-pixel basis until the function
@@ -694,7 +713,7 @@ class Grid2DIterate(Grid2D):
             The results computed by a function using a higher sub-grid size.
         """
 
-        threshold_mask = Mask2D.unmasked(
+        threshold_mask = Mask2D.all_false(
             shape_native=grid_lower_sub_2d.shape_native,
             pixel_scales=grid_lower_sub_2d.pixel_scales,
             invert=True,
@@ -728,11 +747,11 @@ class Grid2DIterate(Grid2D):
         """
         Jitted function to determine the fractional mask, which is a mask where:
 
-        - `True` entries signify the function has been evaluated in that pixel to desired fractional accuracy and
-           therefore does not need to be iteratively computed at higher levels of sub-gridding.
+        - ``True`` entries signify the function has been evaluated in that pixel to desired fractional accuracy and
+          therefore does not need to be iteratively computed at higher levels of sub-gridding.
 
-        - `False` entries signify the function has not been evaluated in that pixel to desired fractional accuracy and
-           therefore must be iterative computed at higher levels of sub-gridding to meet this accuracy.
+        - ``False`` entries signify the function has not been evaluated in that pixel to desired fractional accuracy and
+          therefore must be iterative computed at higher levels of sub-gridding to meet this accuracy.
         """
 
         for y in range(threshold_mask.shape[0]):
@@ -810,7 +829,7 @@ class Grid2DIterate(Grid2D):
         If the function return all zeros, the iteration is terminated early given that all levels of sub-gridding will
         return zeros. This occurs when a function is missing optional objects that contribute to the calculation.
 
-        An example use case of this function is when a "deflections_yx_2d_from" methods in **PyAutoLens**'s `MassProfile`
+        An example use case of this function is when a "deflections_yx_2d_from" methods in **PyAutoLens**'s ``MassProfile``
         module is computed, which by evaluating the function on a higher resolution sub-grid samples the analytic
         mass profile at more points and thus more precisely.
 
@@ -854,7 +873,7 @@ class Grid2DIterate(Grid2D):
                     mask=self.mask, grid_2d_native=iterated_grid, sub_size=1
                 )
 
-                return Grid2D(grid=iterated_grid_1d, mask=self.mask.mask_sub_1)
+                return Grid2D(values=iterated_grid_1d, mask=self.mask.derive_mask.sub_1)
 
             grid_lower_sub_2d = grid_higher_sub
             threshold_mask_lower_sub = threshold_mask_higher_sub
@@ -872,7 +891,7 @@ class Grid2DIterate(Grid2D):
             mask=self.mask, grid_2d_native=iterated_grid_2d, sub_size=1
         )
 
-        return Grid2D(grid=iterated_grid_1d, mask=self.mask.mask_sub_1)
+        return Grid2D(values=iterated_grid_1d, mask=self.mask.derive_mask.sub_1)
 
     @staticmethod
     @numba_util.jit()
@@ -912,9 +931,9 @@ class Grid2DIterate(Grid2D):
 
         Parameters
         ----------
-        func : func
+        func
             The function which is iterated over to compute a more precise evaluation.
-        cls : object
+        cls
             The class the function belongs to.
         """
         result_sub_1_1d = func(cls, self.grid)
