@@ -1,12 +1,19 @@
+from __future__ import annotations
 import numpy as np
-from typing import List, Union, Tuple
+from typing import TYPE_CHECKING, List, Union, Tuple
+
+if TYPE_CHECKING:
+
+    from autoarray.structures.arrays.uniform_1d import Array1D
+    from autoarray.structures.grids.uniform_2d import Grid2D
+    from autoarray.structures.grids.transformed_2d import Grid2DTransformed
+    from autoarray.structures.grids.transformed_2d import Grid2DTransformedNumpy
 
 from autoarray.structures.abstract_structure import Structure
 from autoarray.structures.grids.irregular_2d import Grid2DIrregular
 
 from autoarray.mask.mask_1d import Mask1D
 
-from autoarray import exc
 from autoarray.structures.grids import grid_1d_util
 from autoarray.structures.grids import grid_2d_util
 from autoarray.geometry import geometry_util
@@ -14,7 +21,14 @@ from autoarray import type as ty
 
 
 class Grid1D(Structure):
-    def __new__(cls, grid: np.ndarray, mask: Mask1D, *args, **kwargs):
+    def __new__(
+        cls,
+        values: Union[np.ndarray, List],
+        mask: Mask1D,
+        store_native: bool = False,
+        *args,
+        **kwargs,
+    ):
         """
         A grid of 1D (x) coordinates, which are paired to a uniform 1D mask of pixels and sub-pixels. Each entry
         on the grid corresponds to the (x) coordinates at the centre of a sub-pixel of an unmasked pixel.
@@ -28,8 +42,8 @@ class Grid1D(Structure):
         - native: it retains the original shape of the grid so the ndarray is
           shape [total_y_coordinates*sub_size, total_x_coordinates*sub_size, 2].
 
-        Case 1: [sub-size=1, slim]:
-        -----------------------------------------
+
+        **Case 1 (sub-size=1, slim)**
 
         The Grid1D is an ndarray of shape [total_unmasked_coordinates].
 
@@ -38,31 +52,38 @@ class Grid1D(Structure):
         - grid[3] = the 4th unmasked pixel's x-coordinate.
         - grid[6] = the 7th unmasked pixel's x-coordinate.
 
-        Below is a visual illustration of a grid, where a total of 3 pixels are unmasked and are included in \
-        the grid.
+        Below is a visual illustration of a grid, where a total of 3 pixels are unmasked and are included in the grid.
 
-        x x x o o x o x x x
+        .. code-block:: bash
+
+            <--- -ve  x  +ve -->
+
+            x x x O o x O x x x
 
         This is an example mask.Mask1D, where:
 
-        x = `True` (Pixel is masked and excluded from the grid)
-        o = `False` (Pixel is not masked and included in the grid)
+        .. code-block:: bash
+
+            x = `True` (Pixel is masked and excluded from the grid)
+            O = `False` (Pixel is not masked and included in the grid)
 
         The mask pixel index's will come out like this (and the direction of scaled coordinates is highlighted
         around the mask.
 
-        pixel_scales = 1.0"
+        .. code-block:: bash
 
-        <--- -ve  x  +ve -->
-                                                   x
-         x x x 0 1 x 2 x x x
+            pixel_scales = 1.0"
 
-         grid[0] = [-1.5]
-         grid[1] = [-0.5]
-         grid[2] = [1.5]
+            <--- -ve  x  +ve -->
 
-        Case 2: [sub-size>1, slim]:
-        ------------------
+            x x x 0 1 x 2 x x x
+
+            grid[0] = [-1.5]
+            grid[1] = [-0.5]
+            grid[2] = [1.5]
+
+
+        **Case 2 (sub-size>1, slim)
 
         If the mask's `sub_size` is > 1, the grid is defined as a sub-grid where each entry corresponds to the (x)
         coordinates at the centre of each sub-pixel of an unmasked pixel. The Grid1D is therefore stored as an ndarray
@@ -80,63 +101,72 @@ class Grid1D(Structure):
         contrast to the grid above, our illustration below restricts the mask to just 2 pixels, to keep the
         illustration brief.
 
-        x x x o x o x x x
+        .. code-block:: bash
 
-        This is an example mask.Mask1D, where:
+            x x x O x O x x x
 
-        x = `True` (Pixel is masked and excluded from the grid)
-        o = `False` (Pixel is not masked and included in the grid)
+            This is an example mask.Mask1D, where:
+
+            x = `True` (Pixel is masked and excluded from the grid)
+            O = `False` (Pixel is not masked and included in the grid)
 
         Our grid with a sub-size=1 looks like it did before:
 
-        pixel_scales = 1.0"
+        .. code-block:: bash
 
-        <--- -ve  x  +ve -->
-                                                   x
-         x x x 0 x 1 x x x
+            pixel_scales = 1.0"
+
+            <--- -ve  x  +ve -->
+
+             x x x 0 x 1 x x x
 
         However, if the sub-size is 2, we go to each unmasked pixel and allocate sub-pixel coordinates for it. For
         example, for pixel 0, if `sub_size=2`:
 
-        grid[0] = [-0.75]
-        grid[1] = [-0.25]
+        .. code-block:: bash
+
+            grid[0] = [-0.75]
+            grid[1] = [-0.25]
 
         If we used a sub_size of 3, for the pixel we we would create a 3x3 sub-grid:
 
-        grid[0] = [-0.833]
-        grid[1] = [-0.5]
-        grid[2] = [-0.166]
+        .. code-block:: bash
 
-        Case 3: [sub_size=1 native]
-        --------------------------------------
+            grid[0] = [-0.833]
+            grid[1] = [-0.5]
+            grid[2] = [-0.166]
 
-        The Grid2D has the same properties as Case 1, but is stored as an an ndarray of shape
-        [total_x_coordinates].
+
+        **Case 3 (sub_size=1 native)**
+
+        The Grid2D has the same properties as Case 1, but is stored as an an ndarray of shape [total_x_coordinates].
 
         All masked entries on the grid has (y,x) values of (0.0, 0.0).
 
         For the following example mask:
 
-        x x x o o x o x x x
+        .. code-block:: bash
 
-        - grid[0] = 0.0 (it is masked, thus zero)
-        - grid[1] = 0.0 (it is masked, thus zero)
-        - grid[2] = 0.0 (it is masked, thus zero)
-        - grid[3] = -1.5
-        - grid[4] = -0.5
-        - grid[5] = 0.0 (it is masked, thus zero)
-        - grid[6] = 0.5
+            x x x O O x O x x x
 
-        Case 4: [sub_size>1 native]
-        --------------------------------------
+            - grid[0] = 0.0 (it is masked, thus zero)
+            - grid[1] = 0.0 (it is masked, thus zero)
+            - grid[2] = 0.0 (it is masked, thus zero)
+            - grid[3] = -1.5
+            - grid[4] = -0.5
+            - grid[5] = 0.0 (it is masked, thus zero)
+            - grid[6] = 0.5
+
+
+        **Case 4 (sub_size>1 native)**
 
         The properties of this grid can be derived by combining Case's 2 and 3 above, whereby the grid is stored as
         an ndarray of shape [total_x_coordinates*sub_size,].
 
         All sub-pixels in masked pixels have value 0.0.
 
-        Grid1D Mapping
-        ------------
+
+        **Grid1D Mapping**
 
         Every set of (x) coordinates in a pixel of the sub-grid maps to an unmasked pixel in the mask. For a uniform
         grid, every x coordinate directly corresponds to the location of its paired unmasked pixel.
@@ -152,36 +182,36 @@ class Grid1D(Structure):
 
         Parameters
         ----------
-        grid
+        values
             The (y,x) coordinates of the grid.
         mask
             The 2D mask associated with the grid, defining the pixels each grid coordinate is paired with and
             originates from.
         """
 
-        obj = grid.view(cls)
+        values = grid_1d_util.convert_grid_1d(
+            grid_1d=values, mask_1d=mask, store_native=store_native
+        )
+
+        obj = values.view(cls)
         obj.mask = mask
 
         return obj
 
     @classmethod
-    def manual_slim(
+    def no_mask(
         cls,
-        grid: Union[np.ndarray, List],
+        values: Union[np.ndarray, List],
         pixel_scales: ty.PixelScales,
         sub_size: int = 1,
         origin: Tuple[float] = (0.0,),
     ) -> "Grid1D":
         """
-        Create a Grid1D (see *Grid1D.__new__*) by inputting the grid coordinates in 1D, for example:
-
-        grid=np.array([[1.0, 1.0], [2.0, 2.0], [3.0, 3.0], [4.0, 4.0]])
-
-        grid=[[1.0, 1.0], [2.0, 2.0], [3.0, 3.0], [4.0, 4.0]]
+        Create a Grid1D (see *Grid1D.__new__*) by inputting the grid coordinates in 1D.
 
         Parameters
         ----------
-        grid
+        values
             The (y,x) coordinates of the grid input as an ndarray of shape [total_unmasked_pixells*(sub_size**2), 2]
             or a list of lists.
         pixel_scales
@@ -191,84 +221,41 @@ class Grid1D(Structure):
             The size (sub_size x sub_size) of each unmasked pixels sub-grid.
         origin
             The origin of the grid's mask.
+
+        Examples
+        --------
+
+        .. code-block:: python
+
+            import autogrid as aa
+
+            # Make Grid1D from input np.ndgrid.
+
+            grid_1d = aa.Grid1D.no_mask(grid=np.grid([1.0, 2.0, 3.0, 4.0]), pixel_scales=1.0)
+
+            # Make Grid2D from input list.
+
+            grid_1d = aa.Grid1D.no_mask(grid=[1.0, 2.0, 3.0, 4.0], pixel_scales=1.0)
+
+            # Print grid's slim (masked 1D data representation) and
+            # native (masked 1D data representation)
+
+            print(grid_1d.slim)
+            print(grid_1d.native)
         """
 
         pixel_scales = geometry_util.convert_pixel_scales_1d(pixel_scales=pixel_scales)
 
-        grid = grid_2d_util.convert_grid(grid=grid)
+        values = grid_2d_util.convert_grid(grid=values)
 
-        mask = Mask1D.unmasked(
-            shape_slim=grid.shape[0] // sub_size,
+        mask = Mask1D.all_false(
+            shape_slim=values.shape[0] // sub_size,
             pixel_scales=pixel_scales,
             sub_size=sub_size,
             origin=origin,
         )
 
-        return Grid1D(grid=grid, mask=mask)
-
-    @classmethod
-    def manual_native(
-        cls,
-        grid: Union[np.ndarray, List],
-        pixel_scales: ty.PixelScales,
-        sub_size: int = 1,
-        origin: Tuple[float] = (0.0,),
-    ) -> "Grid1D":
-        """
-        Create a Grid1D (see *Grid1D.__new__*) by inputting the grid coordinates in 1D, for example:
-
-        grid=np.array([[1.0, 1.0], [2.0, 2.0], [3.0, 3.0], [4.0, 4.0]])
-
-        grid=[[1.0, 1.0], [2.0, 2.0], [3.0, 3.0], [4.0, 4.0]]
-
-        Parameters
-        ----------
-        grid or list
-            The (y,x) coordinates of the grid input as an ndarray of shape [total_unmasked_pixells*(sub_size**2), 2]
-            or a list of lists.
-        pixel_scales
-            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
-            it is converted to a (float, float) structure.
-        sub_size
-            The size (sub_size x sub_size) of each unmasked pixels sub-grid.
-        origin
-            The origin of the grid's mask.
-        """
-        return cls.manual_slim(
-            grid=grid, pixel_scales=pixel_scales, sub_size=sub_size, origin=origin
-        )
-
-    @classmethod
-    def manual_mask(cls, grid: Union[np.ndarray, List], mask: Mask1D) -> "Grid1D":
-        """
-        Create a Grid1D (see `Grid1D.__new__`) by inputting the grid coordinates in 1D with their corresponding mask.
-
-        See the manual_slim and manual_native methods for examples.
-
-        Parameters
-        ----------
-        grid or list
-            The (x) coordinates of the grid input as an ndarray of shape [total_coordinates*sub_size] or a list of lists.
-        mask
-            The 1D mask associated with the grid, defining the pixels each grid coordinate is paired with and
-            originates from.
-        """
-
-        grid = grid_2d_util.convert_grid(grid=grid)
-
-        if grid.shape[0] == mask.sub_shape_native[0]:
-
-            grid = grid_1d_util.grid_1d_slim_from(
-                grid_1d_native=grid, mask_1d=mask, sub_size=mask.sub_size
-            )
-
-        elif grid.shape[0] != mask.shape[0]:
-
-            raise exc.GridException(
-                "The grid input into manual_mask does not have matching dimensions with the mask"
-            )
-
-        return Grid1D(grid=grid, mask=mask)
+        return Grid1D(values=values, mask=mask)
 
     @classmethod
     def from_mask(cls, mask: Mask1D) -> "Grid1D":
@@ -291,7 +278,7 @@ class Grid1D(Structure):
             origin=mask.origin,
         )
 
-        return Grid1D(grid=sub_grid_1d, mask=mask)
+        return Grid1D(values=sub_grid_1d, mask=mask)
 
     @classmethod
     def uniform(
@@ -326,8 +313,11 @@ class Grid1D(Structure):
             origin=origin,
         )
 
-        return cls.manual_slim(
-            grid=grid_slim, pixel_scales=pixel_scales, sub_size=sub_size, origin=origin
+        return cls.no_mask(
+            values=grid_slim,
+            pixel_scales=pixel_scales,
+            sub_size=sub_size,
+            origin=origin,
         )
 
     @classmethod
@@ -346,6 +336,7 @@ class Grid1D(Structure):
         pixel_scales
             The (x) scaled units to pixel units conversion factor of every pixel. If this is input as a `float`,
             it is converted to a (float,) tuple.
+            it is converted to a (float,) tuple.
         sub_size
             The size (sub_size) of each unmasked pixels sub-grid.
         """
@@ -357,12 +348,12 @@ class Grid1D(Structure):
 
         grid_slim -= np.min(grid_slim)
 
-        return cls.manual_slim(
-            grid=grid_slim, pixel_scales=pixel_scales, sub_size=sub_size
+        return cls.no_mask(
+            values=grid_slim, pixel_scales=pixel_scales, sub_size=sub_size
         )
 
     @property
-    def slim(self) -> Union["Grid1D"]:
+    def slim(self) -> "Grid1D":
         """
         Return a `Grid1D` where the data is stored its `slim` representation, which is an ndarray of shape
         [total_unmasked_pixels * sub_size, 2].
@@ -370,18 +361,10 @@ class Grid1D(Structure):
         If it is already stored in its `slim` representation  the `Grid1D` is returned as it is. If not, it is
         mapped from  `native` to `slim` and returned as a new `Grid1D`.
         """
-
-        if self.shape[0] != self.mask.sub_shape_native[0]:
-            return self
-
-        grid = grid_1d_util.grid_1d_slim_from(
-            grid_1d_native=self, mask_1d=self.mask, sub_size=self.mask.sub_size
-        )
-
-        return Grid1D(grid=grid, mask=self.mask)
+        return Grid1D(values=self, mask=self.mask)
 
     @property
-    def native(self) -> Union["Grid1D"]:
+    def native(self) -> "Grid1D":
         """
         Return a `Grid1D` where the data is stored in its `native` representation, which is an ndarray of shape
         [sub_size*total_x_pixels, 2].
@@ -389,15 +372,7 @@ class Grid1D(Structure):
         If it is already stored in its `native` representation it is return as it is. If not, it is mapped from
         `slim` to `native` and returned as a new `Grid1D`.
         """
-
-        if self.shape[0] == self.mask.sub_shape_native[0]:
-            return self
-
-        grid = grid_1d_util.grid_1d_native_from(
-            grid_1d_slim=self, mask_1d=self.mask, sub_size=self.mask.sub_size
-        )
-
-        return Grid1D(grid=grid, mask=self.mask)
+        return Grid1D(values=self, mask=self.mask, store_native=True)
 
     @property
     def binned(self) -> "Grid1D":
@@ -419,7 +394,7 @@ class Grid1D(Structure):
             grid_1d_slim.reshape(-1, self.mask.sub_length).sum(axis=1),
         )
 
-        return Grid1D(grid=binned_grid_1d_slim, mask=self.mask.mask_sub_1)
+        return Grid1D(values=binned_grid_1d_slim, mask=self.mask.derive_mask.sub_1)
 
     def grid_2d_radial_projected_from(self, angle: float = 0.0) -> Grid2DIrregular:
         """
@@ -449,24 +424,26 @@ class Grid1D(Structure):
             grid_2d=grid, centre=(0.0, 0.0), angle=angle
         )
 
-        return Grid2DIrregular(grid=grid)
+        return Grid2DIrregular(values=grid)
 
     def structure_2d_from(
         self, result: np.ndarray
-    ) -> Union["Array1D", "Grid2D", "Grid2DTransformed", "Grid2DTransformedNumpy"]:
+    ) -> Union[Array1D, Grid2D, Grid2DTransformed, Grid2DTransformedNumpy]:
         """
         Convert a result from an ndarray to an aa.Array2D or aa.Grid2D structure, where the conversion depends on
         type(result) as follows:
 
-        - 1D np.ndarray   -> aa.Array2D
-        - 2D np.ndarray   -> aa.Grid2D
+        .. code-block:: bash
+
+            - 1D np.ndarray   -> aa.Array2D
+            - 2D np.ndarray   -> aa.Grid2D
 
         This function is used by the grid_2d_to_structure decorator to convert the output result of a function
         to an autoarray structure when a `Grid2D` instance is passed to the decorated function.
 
         Parameters
         ----------
-        result or [np.ndarray]
+        result
             The input result (e.g. of a decorated function) that is converted to a PyAutoArray structure.
         """
         from autoarray.structures.arrays.uniform_1d import Array1D
@@ -475,30 +452,30 @@ class Grid1D(Structure):
         from autoarray.structures.grids.uniform_2d import Grid2D
 
         if len(result.shape) == 1:
-            return Array1D(array=result, mask=self.mask)
+            return Array1D(values=result, mask=self.mask)
 
         if isinstance(result, Grid2DTransformedNumpy):
-            return Grid2DTransformed(grid=result, mask=self.mask)
-        return Grid2D(grid=result, mask=self.mask.to_mask_2d)
+            return Grid2DTransformed(values=result, mask=self.mask)
+        return Grid2D(values=result, mask=self.mask.derive_mask.to_mask_2d)
 
     def structure_2d_list_from(
         self, result_list: List
-    ) -> List[
-        Union["Array1D", "Grid2D", "Grid2DTransformed", "Grid2DTransformedNumpy"]
-    ]:
+    ) -> List[Union[Array1D, Grid2D, Grid2DTransformed, Grid2DTransformedNumpy]]:
         """
         Convert a result from a list of ndarrays to a list of aa.Array2D or aa.Grid2D structure, where the conversion
         depends on type(result) as follows:
 
-        - [1D np.ndarray] -> [aa.Array2D]
-        - [2D np.ndarray] -> [aa.Grid2D]
+        .. code-block:: bash
+
+            - [1D np.ndarray] -> [aa.Array2D]
+            - [2D np.ndarray] -> [aa.Grid2D]
 
         This function is used by the grid_like_list_to_structure-list decorator to convert the output result of a
         function to a list of autoarray structure when a `Grid2D` instance is passed to the decorated function.
 
         Parameters
         ----------
-        result_list or [np.ndarray]
+        result_list
             The input result (e.g. of a decorated function) that is converted to a PyAutoArray structure.
         """
         return [self.structure_2d_from(result=result) for result in result_list]
