@@ -2,13 +2,13 @@ import numpy as np
 from typing import Optional, Union
 
 from autoarray.plot.abstract_plotters import Plotter
-from autoarray.plot.mat_wrap.visuals import Visuals1D
-from autoarray.plot.mat_wrap.visuals import Visuals2D
-from autoarray.plot.mat_wrap.include import Include1D
-from autoarray.plot.mat_wrap.include import Include2D
-from autoarray.plot.mat_wrap.mat_plot import MatPlot1D
-from autoarray.plot.mat_wrap.mat_plot import MatPlot2D
-from autoarray.plot.mat_wrap.mat_plot import AutoLabels
+from autoarray.plot.visuals.one_d import Visuals1D
+from autoarray.plot.visuals.two_d import Visuals2D
+from autoarray.plot.include.one_d import Include1D
+from autoarray.plot.include.two_d import Include2D
+from autoarray.plot.mat_plot.one_d import MatPlot1D
+from autoarray.plot.mat_plot.two_d import MatPlot2D
+from autoarray.plot.auto_labels import AutoLabels
 from autoarray.structures.arrays.uniform_1d import Array1D
 from autoarray.structures.arrays.uniform_2d import Array2D
 from autoarray.structures.grids.uniform_1d import Grid1D
@@ -24,7 +24,7 @@ class Array2DPlotter(Plotter):
         include_2d: Include2D = Include2D(),
     ):
         """
-        Plots `Array2D` objects using the matplotlib method `imshow()` and many other matplotlib functions which 
+        Plots `Array2D` objects using the matplotlib method `imshow()` and many other matplotlib functions which
         customize the plot's appearance.
 
         The `mat_plot_2d` attribute wraps matplotlib function calls to make the figure. By default, the settings
@@ -75,7 +75,7 @@ class Grid2DPlotter(Plotter):
         include_2d: Include2D = Include2D(),
     ):
         """
-        Plots `Grid2D` objects using the matplotlib method `scatter()` and many other matplotlib functions which 
+        Plots `Grid2D` objects using the matplotlib method `scatter()` and many other matplotlib functions which
         customize the plot's appearance.
 
         The `mat_plot_2d` attribute wraps matplotlib function calls to make the figure. By default, the settings
@@ -133,7 +133,7 @@ class YX1DPlotter(Plotter):
         include_1d: Include1D = Include1D(),
     ):
         """
-        Plots two 1D objects using the matplotlib method `plot()` (or a similar method) and many other matplotlib 
+        Plots two 1D objects using the matplotlib method `plot()` (or a similar method) and many other matplotlib
         functions which customize the plot's appearance.
 
         The `mat_plot_1d` attribute wraps matplotlib function calls to make the figure. By default, the settings
