@@ -1,6 +1,6 @@
 import logging
 import numpy as np
-from typing import List, Tuple, Union
+from typing import List, Optional, Tuple, Union
 
 from autoarray.structures.arrays.uniform_2d import Array2D
 from autoarray.structures.grids.uniform_2d import Grid2D
@@ -10,6 +10,7 @@ from autoarray.mask.mask_2d import Mask2D
 from autoarray.structures.grids import grid_2d_util
 from autoarray.geometry import geometry_util
 
+from autoarray import exc
 from autoarray import type as ty
 
 logging.basicConfig()
@@ -19,21 +20,22 @@ logger = logging.getLogger(__name__)
 class VectorYX2D(AbstractVectorYX2D):
     def __new__(
         cls,
-        vectors: Union[np.ndarray, List[Tuple[float, float]]],
+        values: Union[np.ndarray, List[Tuple[float, float]]],
         grid: Union[Grid2D, List],
-        mask,
+        mask: Mask2D,
+        store_native: bool = False,
     ):
         """
         A collection of (y,x) vectors which are located on a regular 2D grid of (y,x) coordinates.
 
-        The vectors are paired to a uniform 2D mask of pixels and sub-pixels. Each vector corresponds to a value at 
+        The vectors are paired to a uniform 2D mask of pixels and sub-pixels. Each vector corresponds to a value at
         the centre of a sub-pixel in an unmasked pixel.
 
         The `VectorYX2D` is ordered such that pixels begin from the top-row of the corresponding mask and go right
         and down. The positive y-axis is upwards and positive x-axis to the right.
 
-        The (y,x) vectors are stored as a NumPy array which has the `slim` and `native shapes described below. 
-        Irrespective of this shape, the last dimension of the data structure storing the vectors is always shape 2, 
+        The (y,x) vectors are stored as a NumPy array which has the `slim` and `native shapes described below.
+        Irrespective of this shape, the last dimension of the data structure storing the vectors is always shape 2,
         corresponding to the y and x vectors. [total_vectors, 2].
 
         Calculations should use the NumPy array structure wherever possible for efficient calculations.
@@ -44,11 +46,11 @@ class VectorYX2D(AbstractVectorYX2D):
         [[vector_0_y, vector_0_x], [vector_1_y, vector_1_x]]
         [(vector_0_y, vector_0_x), (vector_1_y, vector_1_x)]
 
-        If your vector field lies on a 2D irregular grid of data the `VectorFieldIrregular2D` data structure should be 
+        If your vector field lies on a 2D irregular grid of data the `VectorFieldIrregular2D` data structure should be
         used.
 
-        Case 1: [sub-size=1, slim]:
-        ---------------------------
+
+        **Case 1 (sub-size=1, slim)**
 
         The Vector2D is an ndarray of shape [total_unmasked_pixels, 2].
 
@@ -60,16 +62,16 @@ class VectorYX2D(AbstractVectorYX2D):
         Below is a visual illustration of a vector, where a total of 10 pixels are unmasked and are included in
         the vector.
 
-        IxIxIxIxIxIxIxIxIxIxI
-        IxIxIxIxIxIxIxIxIxIxI     This is an example `Mask2D`, where:
-        IxIxIxIxIxIxIxIxIxIxI
-        IxIxIxIxIoIoIxIxIxIxI     x = `True` (Pixel is masked and excluded from the vector)
-        IxIxIxIoIoIoIoIxIxIxI     o = `False` (Pixel is not masked and included in the vector)
-        IxIxIxIoIoIoIoIxIxIxI
-        IxIxIxIxIxIxIxIxIxIxI
-        IxIxIxIxIxIxIxIxIxIxI
-        IxIxIxIxIxIxIxIxIxIxI
-        IxIxIxIxIxIxIxIxIxIxI
+         x x x x x x x x x x
+         x x x x x x x x x x     This is an example `Mask2D`, where:
+         x x x x x x x x x x
+         x x x x O O x x x x     x = `True` (Pixel is masked and excluded from the vector)
+         x x x O O O O x x x     O = `False` (Pixel is not masked and included in the vector)
+         x x x O O O O x x x
+         x x x x x x x x x x
+         x x x x x x x x x x
+         x x x x x x x x x x
+         x x x x x x x x x x
 
         The mask pixel index's will come out like this (and the direction of scaled values is highlighted
         around the mask).
@@ -78,21 +80,21 @@ class VectorYX2D(AbstractVectorYX2D):
 
         <--- -ve  x  +ve -->
                                                         y      x
-        IxIxIxIxIxIxIxIxIxIxI  ^   vector[0, :] = 0
-        IxIxIxIxIxIxIxIxIxIxI  I   vector[1, :] = 1
-        IxIxIxIxIxIxIxIxIxIxI  I   vector[2, :] = 2
-        IxIxIxIxI0I1IxIxIxIxI +ve  vector[3, :] = 3
-        IxIxIxI2I3I4I5IxIxIxI  y   vector[4, :] = 4
-        IxIxIxI6I7I8I9IxIxIxI -ve  vector[5, :] = 5
-        IxIxIxIxIxIxIxIxIxIxI  I   vector[6, :] = 6
-        IxIxIxIxIxIxIxIxIxIxI  I   vector[7, :] = 7
-        IxIxIxIxIxIxIxIxIxIxI \/   vector[8, :] = 8
-        IxIxIxIxIxIxIxIxIxIxI      vector[9, :] = 9
+         x x x x x x x x x x  ^   vector[0, :] = 0
+         x x x x x x x x x x  I   vector[1, :] = 1
+         x x x x x x x x x x  I   vector[2, :] = 2
+         x x x x 0 1 x x x x +ve  vector[3, :] = 3
+         x x x 2 3 4 5 x x x  y   vector[4, :] = 4
+         x x x 6 7 8 9 x x x -ve  vector[5, :] = 5
+         x x x x x x x x x x  I   vector[6, :] = 6
+         x x x x x x x x x x  I   vector[7, :] = 7
+         x x x x x x x x x x \/   vector[8, :] = 8
+         x x x x x x x x x x      vector[9, :] = 9
 
-        Case 2: [sub-size>1, slim]:
-        ------------------
 
-        If the masks's sub size is > 1, the vector is defined as a sub-vector where each entry corresponds to the 
+        **Case 2 (sub-size>1, slim)**
+
+        If the masks's sub size is > 1, the vector is defined as a sub-vector where each entry corresponds to the
         values at the centre of each sub-pixel of an unmasked pixel.
 
         The sub-vector indexes are ordered such that pixels begin from the first (top-left) sub-pixel in the first
@@ -107,33 +109,31 @@ class VectorYX2D(AbstractVectorYX2D):
         contrast to the vector above, our illustration below restricts the mask to just 2 pixels, to keep the
         illustration brief.
 
-        IxIxIxIxIxIxIxIxIxIxI
-        IxIxIxIxIxIxIxIxIxIxI     This is an example `Mask2D`, where:
-        IxIxIxIxIxIxIxIxIxIxI
-        IxIxIxIxIxIxIxIxIxIxI     x = `True` (Pixel is masked and excluded from lens)
-        IxIxIxIxIoIoIxIxIxIxI     o = `False` (Pixel is not masked and included in lens)
-        IxIxIxIxIxIxIxIxIxIxI
-        IxIxIxIxIxIxIxIxIxIxI
-        IxIxIxIxIxIxIxIxIxIxI
-        IxIxIxIxIxIxIxIxIxIxI
-        IxIxIxIxIxIxIxIxIxIxI
+         x x x x x x x x x x
+         x x x x x x x x x x     This is an example `Mask2D`, where:
+         x x x x x x x x x x
+         x x x x x x x x x x     x = `True` (Pixel is masked and excluded from lens)
+         x x x x O O x x x x     O = `False` (Pixel is not masked and included in lens)
+         x x x x x x x x x x
+         x x x x x x x x x x
+         x x x x x x x x x x
+         x x x x x x x x x x
+         x x x x x x x x x x
 
         Our vector with a sub-size looks like it did before:
 
-        pixel_scales = 1.0"
-
         <--- -ve  x  +ve -->
 
-        IxIxIxIxIxIxIxIxIxIxI  ^
-        IxIxIxIxIxIxIxIxIxIxI  I
-        IxIxIxIxIxIxIxIxIxIxI  I
-        IxIxIxIxIxIxIxIxIxIxI +ve
-        IxIxIxI0I1IxIxIxIxIxI  y
-        IxIxIxIxIxIxIxIxIxIxI -ve
-        IxIxIxIxIxIxIxIxIxIxI  I
-        IxIxIxIxIxIxIxIxIxIxI  I
-        IxIxIxIxIxIxIxIxIxIxI \/
-        IxIxIxIxIxIxIxIxIxIxI
+         x x x x x x x x x x  ^
+         x x x x x x x x x x  I
+         x x x x x x x x x x  I
+         x x x x x x x x x x +ve
+         x x x 0 1 x x x x x  y
+         x x x x x x x x x x -ve
+         x x x x x x x x x x  I
+         x x x x x x x x x x  I
+         x x x x x x x x x x \/
+         x x x x x x x x x x
 
         However, if the sub-size is 2,each unmasked pixel has a set of sub-pixels with values. For example, for pixel 0,
         if `sub_size=2`, it has 4 values on a 2x2 sub-vector:
@@ -158,8 +158,8 @@ class VectorYX2D(AbstractVectorYX2D):
                  vector[7] = y and x values of first sub-pixel in pixel 7.
                  vector[8] = y and x values of first sub-pixel in pixel 8.
 
-        Case 3: [sub_size=1, native]
-        ----------------------------
+
+        **Case 3 (sub_size=1, native)**
 
         The Vector2D has the same properties as Case 1, but is stored as an an ndarray of shape
         [total_y_values, total_x_values, 2].
@@ -168,26 +168,28 @@ class VectorYX2D(AbstractVectorYX2D):
 
         For the following example mask:
 
-        IxIxIxIxIxIxIxIxIxIxI
-        IxIxIxIxIxIxIxIxIxIxI     This is an example `Mask2D`, where:
-        IxIxIxIxIxIxIxIxIxIxI
-        IxIxIxIxIoIoIxIxIxIxI     x = `True` (Pixel is masked and excluded from the vector)
-        IxIxIxIoIoIoIoIxIxIxI     o = `False` (Pixel is not masked and included in the vector)
-        IxIxIxIoIoIoIoIxIxIxI
-        IxIxIxIxIxIxIxIxIxIxI
-        IxIxIxIxIxIxIxIxIxIxI
-        IxIxIxIxIxIxIxIxIxIxI
-        IxIxIxIxIxIxIxIxIxIxI
+         x x x x x x x x x x
+         x x x x x x x x x x     This is an example `Mask2D`, where:
+         x x x x x x x x x x
+         x x x x O O x x x x     x = `True` (Pixel is masked and excluded from the vector)
+         x x x O O O O x x x     O = `False` (Pixel is not masked and included in the vector)
+         x x x O O O O x x x
+         x x x x x x x x x x
+         x x x x x x x x x x
+         x x x x x x x x x x
+         x x x x x x x x x x
 
-        - vector[0,0, 0:2] = [0.0, 0.0] (it is masked, thus zero)
-        - vector[0,0, 0:2] = [0.0, 0.0] (it is masked, thus zero)
-        - vector[3,3, 0:2] = [0.0, 0.0] (it is masked, thus zero)
-        - vector[3,3, 0:2] = [0.0, 0.0] (it is masked, thus zero)
-        - vector[3,4, 0:2] = [0, 0]
-        - vector[3,4, 0:2] = [-1, -1]
+        For the example above:
 
-        Case 4: [sub_size>, native]
-        ---------------------------
+            - vector[0,0, 0:2] = [0.0, 0.0] (it is masked, thus zero)
+            - vector[0,0, 0:2] = [0.0, 0.0] (it is masked, thus zero)
+            - vector[3,3, 0:2] = [0.0, 0.0] (it is masked, thus zero)
+            - vector[3,3, 0:2] = [0.0, 0.0] (it is masked, thus zero)
+            - vector[3,4, 0:2] = [0, 0]
+            - vector[3,4, 0:2] = [-1, -1]
+
+
+        **Case 4: (sub_size>, native)**
 
         The properties of this vector can be derived by combining Case's 2 and 3 above, whereby the vector is stored as
         an ndarray of shape [total_y_values*sub_size, total_x_values*sub_size, 2].
@@ -196,23 +198,34 @@ class VectorYX2D(AbstractVectorYX2D):
 
         Parameters
         ----------
-        vectors
+        values
             The 2D (y,x) vectors on a regular grid that represent the vector-field.
         grid
             The regular grid of (y,x) coordinates where each vector is located.
         mask
             The 2D mask associated with the array, defining the pixels each array value is paired with and
-            originates from.            
+            originates from.
+        store_native
+            If True, the ndarray is stored in its native format [total_y_pixels, total_x_pixels, 2]. This avoids
+            mapping large data arrays to and from the slim / native formats, which can be a computational bottleneck.
         """
 
-        if len(vectors) == 0:
+        if len(values) == 0:
             return []
 
-        if type(vectors) is list:
-            vectors = np.asarray(vectors)
+        if type(values) is list:
+            values = np.asarray(values)
 
-        obj = vectors.view(cls)
-        obj.grid = Grid2D(grid=grid, mask=mask)
+        values = grid_2d_util.convert_grid_2d(
+            grid_2d=values, mask_2d=mask, store_native=store_native
+        )
+
+        grid = grid_2d_util.convert_grid_2d(
+            grid_2d=grid, mask_2d=mask, store_native=store_native
+        )
+
+        obj = values.view(cls)
+        obj.grid = Grid2D(values=grid, mask=mask)
         obj.mask = mask
 
         return obj
@@ -226,11 +239,11 @@ class VectorYX2D(AbstractVectorYX2D):
             self.grid = obj.grid
 
     @classmethod
-    def manual_slim(
+    def no_mask(
         cls,
-        vectors: Union[np.ndarray, List[List], List[Tuple]],
-        shape_native: Tuple[int, int],
+        values: Union[np.ndarray, List[List], List[Tuple]],
         pixel_scales: ty.PixelScales,
+        shape_native: Optional[Tuple[int, int]] = None,
         sub_size: int = 1,
         origin: Tuple[float, float] = (0.0, 0.0),
     ) -> "VectorYX2D":
@@ -246,9 +259,12 @@ class VectorYX2D(AbstractVectorYX2D):
         From 1D input the method cannot determine the 2D shape of the grid and its mask, thus the `shape_native` must be
         input into this method. The mask is setup as a unmasked `Mask2D` of shape_native.
 
+        The 2D shape of the grid and its mask are determined from the input grid and the mask is setup as an
+        unmasked `Mask2D` of shape_native.
+
         Parameters
         ----------
-        vectors
+        values
             The (y,x) vectors input as an ndarray of shape [total_unmasked_pixells*(sub_size**2), 2] or a list of lists.
         shape_native
             The 2D shape of the mask the grid is paired with.
@@ -263,76 +279,36 @@ class VectorYX2D(AbstractVectorYX2D):
 
         pixel_scales = geometry_util.convert_pixel_scales_2d(pixel_scales=pixel_scales)
 
-        grid = Grid2D.uniform(
-            shape_native=shape_native,
-            pixel_scales=pixel_scales,
-            sub_size=sub_size,
-            origin=origin,
-        )
+        values = grid_2d_util.convert_grid(grid=values)
 
-        mask = Mask2D.unmasked(
-            shape_native=shape_native,
-            pixel_scales=pixel_scales,
-            sub_size=sub_size,
-            origin=origin,
-        )
+        if len(values.shape) == 2:
 
-        vectors = grid_2d_util.convert_grid_2d(grid_2d=vectors, mask_2d=mask)
+            if shape_native is None:
+                raise exc.VectorYXException(
+                    f"""
+                    The input vectors are not in their native shape (an ndarray / list of 
+                    shape [total_y_pixels, total_x_pixels, 2]) and the shape_native parameter has not been input the 
+                    VectorYX2D function.
+    
+                    Either change the input array to be its native shape or input its shape_native input the function.
+    
+                    The shape of the input array is {values.shape}
+                    """
+                )
 
-        return cls(vectors=vectors, grid=grid, mask=mask)
+            if shape_native and len(shape_native) != 2:
+                raise exc.GridException(
+                    """
+                    The input shape_native parameter is not a tuple of type (int, int).
+                    """
+                )
 
-    @classmethod
-    def manual_native(
-        cls,
-        vectors: Union[np.ndarray, List],
-        pixel_scales: ty.PixelScales,
-        sub_size: int = 1,
-        origin: Tuple[float, float] = (0.0, 0.0),
-    ) -> "VectorYX2D":
-        """
-        Create a VectorYX2D (see *VectorYX2D.__new__*) by inputting the grid coordinates in 2D, for example:
+        else:
 
-        vectors=np.ndarray([[[1.0, 1.0], [2.0, 2.0]],
-                         [[3.0, 3.0], [4.0, 4.0]]])
-
-        vectors=[[[1.0, 1.0], [2.0, 2.0]],
-                [[3.0, 3.0], [4.0, 4.0]]]
-
-        The `VectorYX2D` object assumes a uniform `Grid2D` which is computed from the mask's `shape_native`,
-        `pixel_scales` and `origin`.
-
-        The 2D shape of the grid and its mask are determined from the input grid and the mask is setup as an
-        unmasked `Mask2D` of shape_native.
-
-        Parameters
-        ----------
-        grid
-            The (y,x) coordinates of the grid input as an ndarray of shape
-            [total_y_coordinates*sub_size, total_x_pixel*sub_size, 2] or a list of lists.
-        pixel_scales
-            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
-            it is converted to a (float, float) structure.
-        sub_size
-            The size (sub_size x sub_size) of each unmasked pixels sub-grid.
-        origin
-            The origin of the grid's mask.
-        """
-
-        vectors = grid_2d_util.convert_grid(grid=vectors)
-
-        pixel_scales = geometry_util.convert_pixel_scales_2d(pixel_scales=pixel_scales)
-
-        shape_native = (
-            int(vectors.shape[0] / sub_size),
-            int(vectors.shape[1] / sub_size),
-        )
-
-        mask = Mask2D.unmasked(
-            shape_native=shape_native,
-            pixel_scales=pixel_scales,
-            sub_size=sub_size,
-            origin=origin,
-        )
+            shape_native = (
+                int(values.shape[0] / sub_size),
+                int(values.shape[1] / sub_size),
+            )
 
         grid = Grid2D.uniform(
             shape_native=shape_native,
@@ -341,14 +317,17 @@ class VectorYX2D(AbstractVectorYX2D):
             origin=origin,
         )
 
-        vectors = grid_2d_util.convert_grid_2d(grid_2d=vectors, mask_2d=mask)
+        mask = Mask2D.all_false(
+            shape_native=shape_native,
+            pixel_scales=pixel_scales,
+            sub_size=sub_size,
+            origin=origin,
+        )
 
-        return VectorYX2D(vectors=vectors, grid=grid, mask=mask)
+        return cls(values=values, grid=grid, mask=mask)
 
     @classmethod
-    def manual_mask(
-        cls, vectors: Union[np.ndarray, List], mask: Mask2D
-    ) -> "VectorYX2D":
+    def from_mask(cls, values: Union[np.ndarray, List], mask: Mask2D) -> "VectorYX2D":
         """
         Create a VectorYX2D (see *VectorYX2D.__new__*) by inputting the vectors in 1D or 2D with its mask,
         for example:
@@ -358,7 +337,7 @@ class VectorYX2D(AbstractVectorYX2D):
 
         Parameters
         ----------
-        array
+        values
             The values of the array input as an ndarray of shape [total_unmasked_pixels*(sub_size**2)] or a list of
             lists.
         mask
@@ -367,8 +346,7 @@ class VectorYX2D(AbstractVectorYX2D):
 
         grid = Grid2D.from_mask(mask=mask)
 
-        vectors = grid_2d_util.convert_grid_2d(grid_2d=vectors, mask_2d=mask)
-        return VectorYX2D(vectors=vectors, grid=grid, mask=mask)
+        return VectorYX2D(values=values, grid=grid, mask=mask)
 
     @classmethod
     def full(
@@ -403,8 +381,8 @@ class VectorYX2D(AbstractVectorYX2D):
         if sub_size is not None:
             shape_native = (shape_native[0] * sub_size, shape_native[1] * sub_size)
 
-        return cls.manual_native(
-            vectors=np.full(
+        return cls.no_mask(
+            values=np.full(
                 fill_value=fill_value, shape=(shape_native[0], shape_native[1], 2)
             ),
             pixel_scales=pixel_scales,
@@ -421,7 +399,7 @@ class VectorYX2D(AbstractVectorYX2D):
         origin: Tuple[float, float] = (0.0, 0.0),
     ) -> "VectorYX2D":
         """
-        Create a `VectorYX2D` (see `AbstractVectorYX2D.__new__`) where all values are filled with 1.0, analogous to 
+        Create a `VectorYX2D` (see `AbstractVectorYX2D.__new__`) where all values are filled with 1.0, analogous to
         the method np.ones().
 
         From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_native must be
@@ -456,7 +434,7 @@ class VectorYX2D(AbstractVectorYX2D):
         origin: Tuple[float, float] = (0.0, 0.0),
     ) -> "VectorYX2D":
         """
-        Create a `VectorYX2D` (see `AbstractVectorYX2D.__new__`) where all values are filled with 1.0, analogous to 
+        Create a `VectorYX2D` (see `AbstractVectorYX2D.__new__`) where all values are filled with 1.0, analogous to
         the method np.zeros().
 
         From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_native must be
@@ -491,14 +469,7 @@ class VectorYX2D(AbstractVectorYX2D):
         If it is already stored in its `slim` representation it is returned as it is. If not, it is  mapped from
         `native` to `slim` and returned as a new `Array2D`.
         """
-        if len(self.shape) == 2:
-            return self
-
-        vectors_2d_slim = grid_2d_util.grid_2d_slim_from(
-            grid_2d_native=self, mask=self.mask, sub_size=self.mask.sub_size
-        )
-
-        return VectorYX2D(vectors=vectors_2d_slim, grid=self.grid.slim, mask=self.mask)
+        return VectorYX2D(values=self, grid=self.grid.slim, mask=self.mask)
 
     @property
     def native(self) -> "VectorYX2D":
@@ -509,16 +480,11 @@ class VectorYX2D(AbstractVectorYX2D):
         If it is already stored in its `native` representation it is return as it is. If not, it is mapped from
         `slim` to `native` and returned as a new `Grid2D`.
         """
-
-        if len(self.shape) != 2:
-            return self
-
-        vectors_2d_native = grid_2d_util.grid_2d_native_from(
-            grid_2d_slim=self, mask_2d=self.mask, sub_size=self.mask.sub_size
-        )
-
         return VectorYX2D(
-            vectors=vectors_2d_native, grid=self.grid.native, mask=self.mask
+            values=self,
+            grid=self.grid.native,
+            mask=self.mask,
+            store_native=True,
         )
 
     @property
@@ -544,15 +510,15 @@ class VectorYX2D(AbstractVectorYX2D):
         )
 
         return VectorYX2D(
-            vectors=np.stack(
+            values=np.stack(
                 (vector_2d_slim_binned_y, vector_2d_slim_binned_x), axis=-1
             ),
             grid=self.grid.binned,
-            mask=self.mask.mask_sub_1,
+            mask=self.mask.derive_mask.sub_1,
         )
 
     def apply_mask(self, mask: Mask2D) -> "VectorYX2D":
-        return VectorYX2D.manual_mask(vectors=self.native, mask=mask)
+        return VectorYX2D.from_mask(values=self.native, mask=mask)
 
     @property
     def magnitudes(self) -> Array2D:
@@ -560,7 +526,7 @@ class VectorYX2D(AbstractVectorYX2D):
         Returns the magnitude of every vector which are computed as sqrt(y**2 + x**2).
         """
         return Array2D(
-            array=np.sqrt(self[:, 0] ** 2.0 + self[:, 1] ** 2.0), mask=self.mask
+            values=np.sqrt(self[:, 0] ** 2.0 + self[:, 1] ** 2.0), mask=self.mask
         )
 
     @property
@@ -568,11 +534,11 @@ class VectorYX2D(AbstractVectorYX2D):
         """
         Returns the y vector values as an `Array2D` object.
         """
-        return Array2D(array=self.slim[:, 0], mask=self.mask)
+        return Array2D(values=self.slim[:, 0], mask=self.mask)
 
     @property
     def x(self) -> Array2D:
         """
         Returns the y vector values as an `Array2D` object.
         """
-        return Array2D(array=self.slim[:, 1], mask=self.mask)
+        return Array2D(values=self.slim[:, 1], mask=self.mask)
