@@ -79,12 +79,16 @@ class AbstractVisibilities(Structure):
         """
         Returns the 1D complex NumPy array of values as an irregular grid.
         """
-        return Grid2DIrregular(grid=self.in_array)
+        return Grid2DIrregular(values=self.in_array)
 
     @property
     def shape_slim(self) -> int:
         return self.shape[0]
 
+    @property
+    def mask(self):
+        return np.full(fill_value=False, shape=self.shape)
+
     @cached_property
     def amplitudes(self) -> np.ndarray:
         return np.sqrt(np.square(self.real) + np.square(self.imag))
@@ -126,41 +130,8 @@ class AbstractVisibilities(Structure):
         """
         return np.min(self.real), np.min(self.imag)
 
-    @property
-    def extent(self) -> np.ndarray:
-        """
-        The extent of the visibilities if they are treated as a 2D grid in the complex plane.
-        """
-        return np.array(
-            [
-                self.scaled_minima[1],
-                self.scaled_maxima[1],
-                self.scaled_minima[0],
-                self.scaled_maxima[0],
-            ]
-        )
-
 
 class Visibilities(AbstractVisibilities):
-    @classmethod
-    def manual_slim(
-        cls, visibilities: Union[np.ndarray, List[complex]]
-    ) -> "Visibilities":
-        """
-        Create `Visibilities` (see `AbstractVisibilities.__new__`) by inputting (real, imag) values as a 1D complex
-        NumPy array or 2D NumPy float array or list, for example:
-
-        visibilities=np.array([1.0+1.0j, 2.0+2.0j, 3.0+3.0j, 4.0+4.0j])
-        visibilities=np.array([[1.0+1.0], [2.0+2.0], [3.0+3.0], [4.0+4.0]])
-        visibilities=[[1.0, 1.0], [2.0, 2.0], [3.0, 3.0], [4.0, 4.0]]
-
-        Parameters
-        ----------
-        visibilities
-            The (real, imag) visibilities values.
-        """
-        return cls(visibilities)
-
     @classmethod
     def full(cls, fill_value: float, shape_slim: Tuple[int]) -> "Visibilities":
         """
@@ -177,7 +148,7 @@ class Visibilities(AbstractVisibilities):
         shape_slim
             The 1D shape of output visibilities.
         """
-        return cls.manual_slim(
+        return cls(
             visibilities=np.full(
                 fill_value=fill_value + fill_value * 1j, shape=(shape_slim[0],)
             )
@@ -234,7 +205,7 @@ class Visibilities(AbstractVisibilities):
         visibilities_1d = array_2d_util.numpy_array_2d_via_fits_from(
             file_path=file_path, hdu=hdu
         )
-        return cls.manual_slim(visibilities=visibilities_1d)
+        return cls(visibilities=visibilities_1d)
 
 
 class VisibilitiesNoiseMap(Visibilities):
@@ -246,7 +217,7 @@ class VisibilitiesNoiseMap(Visibilities):
         an `Interferometer` dataset.
 
         This data structure behaves the same as the `Visibilities` structure (see `AbstractVisibilities.__new__`). The
-        only difference is that it includes a `WeightOperator` used by `LEq`'s which use `LinearOperators` and
+        only difference is that it includes a `WeightOperator` used by `Inversion`'s which use `LinearOperators` and
         the library `PyLops` to fit `Interferometer` data.
 
         Parameters
@@ -274,7 +245,7 @@ class VisibilitiesNoiseMap(Visibilities):
             (np.real(visibilities), np.imag(visibilities)), axis=0
         )
 
-        weight_list = 1.0 / obj.in_array ** 2.0
+        weight_list = 1.0 / obj.in_array**2.0
 
         obj.weight_list_ordered_1d = np.concatenate(
             (weight_list[:, 0], weight_list[:, 1]), axis=0
