@@ -9,9 +9,15 @@ from autoarray.structures.grids import grid_2d_util as grid_2d
 from autoarray.structures.grids import sparse_2d_util as sparse
 from autoarray.layout import layout_util as layout
 from autoarray.fit import fit_util as fit
-from autoarray.inversion.pixelizations import pixelization_util as pixelization
-from autoarray.inversion.mappers import mapper_util as mapper
+from autoarray.inversion.pixelization.mesh import mesh_util as mesh
+from autoarray.inversion.pixelization.mappers import mapper_util as mapper
 from autoarray.inversion.regularization import regularization_util as regularization
-from autoarray.inversion.linear_eqn import leq_util as leq
 from autoarray.inversion.inversion import inversion_util as inversion
+from autoarray.inversion.inversion.imaging import (
+    inversion_imaging_util as inversion_imaging,
+)
+from autoarray.inversion.inversion.interferometer import (
+    inversion_interferometer_util as inversion_interferometer,
+)
 from autoarray.operators import transformer_util as transformer
+from autoarray.util import misc_util as misc
